/*
	file automatically generated by make_test_files.pl
	Thu Jan  5 10:43:19 2006
*/

/*****************************************************************************
 *                                                                           *
 *          UNURAN -- Universal Non-Uniform Random number generator          *
 *                                                                           *
 *****************************************************************************/
    
/**
 ** Tests for AROU
 **/
    
/*---------------------------------------------------------------------------*/
#include "testunuran.h"
/*---------------------------------------------------------------------------*/

/*---------------------------------------------------------------------------*/
/* global variables                                                          */

static FILE *TESTLOG;               /* test log file                         */
static FILE *UNURANLOG;             /* unuran log file                       */

static int test_ok = TRUE;          /* all tests ok (boolean)                */
static int n_tests_failed;          /* number of failed tests                */

/*---------------------------------------------------------------------------*/

void run_verify_generator( FILE *LOG, int line, UNUR_PAR *par );

int unur_arou_set_verify( UNUR_PAR *par, int );

/*---------------------------------------------------------------------------*/



/* prototypes */
double pdf( double x, const UNUR_DISTR *distr );

double pdf_bimodal( double x, const UNUR_DISTR *distr );
double dpdf_bimodal( double x, const UNUR_DISTR *distr );

double pdf_negative( double x, const UNUR_DISTR *distr );
double dpdf_negative( double x, const UNUR_DISTR *distr );

double pdf_partnegative( double x, const UNUR_DISTR *distr );
double dpdf_partnegative( double x, const UNUR_DISTR *distr );

double pdf_sqrtlin( double x, const UNUR_DISTR *distr );
double dpdf_sqrtlin( double x, const UNUR_DISTR *distr );
double cdf_sqrtlin( double x, const UNUR_DISTR *distr );

double pdf_sqrtlinshft(double x, const UNUR_DISTR *distr );
double dpdf_sqrtlinshft( double x, const UNUR_DISTR *distr );
double cdf_sqrtlinshft( double x, const UNUR_DISTR *distr );

#define COMPARE_SAMPLE_SIZE  (10000)
#define VIOLATE_SAMPLE_SIZE  (20)




/*---------------------------------------------------------------------------*/

#ifndef CHI2_FAILURES_TOLERATED
#  define CHI2_FAILURES_TOLERATED DEFAULT_CHI2_FAILURES_TOLERATED
#endif

/*---------------------------------------------------------------------------*/
/* [verbatim] */



/* pdf of bimodal density */
double pdf_bimodal( double x, const UNUR_DISTR *distr )
{ 
	return ( exp(-(x-1.)*(x-1.)) + exp(-(x+1.)*(x+1.)) );
}
double dpdf_bimodal( double x, const UNUR_DISTR *distr )
{ 
	return ( -2. * (x-1.) * exp(-(x-1.)*(x-1.)) -2. * (x+1.) * exp(-(x+1.)*(x+1.)) );
}

/* pdf with negative value */
double pdf_negative( double x, const UNUR_DISTR *distr )  { return (-x*x); }
double dpdf_negative( double x, const UNUR_DISTR *distr ) { return (-2.*x); }

/* pdf with partial negative value */
double pdf_partnegative( double x, const UNUR_DISTR *distr )  
{ 
	return ((x>-0.89 && x<0.89) ? -1.: exp(-x*x)); 
}
double dpdf_partnegative( double x, const UNUR_DISTR *distr ) 
{
	return ((x>-0.89 && x<0.89) ?0.: -2.*x*exp(-x*x));
}

/* pdf of normal density */
double pdf( double x, const UNUR_DISTR *distr )
{ 
	return exp(-x*x/2.);
} /* end of pdf */

/* pdf with piecewise linear function as transformed density with T = -1/sqrt */
double pdf_sqrtlin( double x, const UNUR_DISTR *distr )
{ 
	double y = 1./(fabs(x)+1.);
	return y*y;
}
double dpdf_sqrtlin( double x, const UNUR_DISTR *distr )
{ 
	double y = 1./(fabs(x)+1.);
	y = 2.*y*y*y;
	return ((x<0.) ? y : - y);
}
double cdf_sqrtlin( double x, const UNUR_DISTR *distr )
{ 
	if (x<=0.)
		return 0.5/(1.-x);
	else
		return (1.-0.5/(1.+x));
}

/* pdf with piecewise linear function as transformed density with T = -1/sqrt and shifted mode */
double pdf_sqrtlinshft( double x, const UNUR_DISTR *distr )
{ 
	double y;
	x -= 1.;
	y = 1./(fabs(x)+1.);
	return y*y;
}
double dpdf_sqrtlinshft( double x, const UNUR_DISTR *distr )
{ 
	double y;
	x -= 1.;
	y = 1./(fabs(x)+1.);
	y = 2.*y*y*y;
	return ((x<0.) ? y : - y);
}
double cdf_sqrtlinshft( double x, const UNUR_DISTR *distr )
{ 
	x -= 1.;
	if (x<=0.)
		return 0.5/(1.-x);
	else
		return (1.-0.5/(1.+x));
}

/*---------------------------------------------------------------------------*/
/* [new] */

void test_new (void)
{
	/* start test */
	printf("[new "); fflush(stdout);
	fprintf(TESTLOG,"\n[new]\n");

	/* reset counter */
	n_tests_failed = 0;
  
{ /* invalid NULL ptr */
UNUR_DISTR *distr = NULL;
   distr = NULL; 


unur_errno = 0;
n_tests_failed += (check_expected_NULL(TESTLOG,44,(unur_arou_new( distr )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,44,UNUR_ERR_NULL)==UNUR_SUCCESS)?0:1;
unur_distr_free(distr);
}

{ /* invalid distribution type */
UNUR_DISTR *distr = NULL;
   distr = unur_distr_discr_new(); 


unur_errno = 0;
n_tests_failed += (check_expected_NULL(TESTLOG,50,(unur_arou_new( distr )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,50,UNUR_ERR_DISTR_INVALID)==UNUR_SUCCESS)?0:1;
unur_distr_free(distr);
}

{ /* data missing in distribution object */
UNUR_DISTR *distr = NULL;
   distr = unur_distr_cont_new(); 


unur_errno = 0;
/* pdf, dpdf */
n_tests_failed += (check_expected_NULL(TESTLOG,57,(unur_arou_new( distr )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,57,UNUR_ERR_DISTR_REQUIRED)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
/* dpdf */
unur_distr_cont_set_pdf(distr,pdf);
n_tests_failed += (check_expected_NULL(TESTLOG,62,(unur_arou_new( distr )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,62,UNUR_ERR_DISTR_REQUIRED)==UNUR_SUCCESS)?0:1;
unur_distr_free(distr);
}


	/* test finished */
	test_ok &= (n_tests_failed) ? 0 : 1;
	(n_tests_failed) ? printf(" ==> failed] ") : printf(" ==> ok] ");

#if WITH_DMALLOC
	dmalloc_vmessage("section = new  ================================\n",NULL);
	dmalloc_log_unfreed();
#endif

} /* end of test_new() */

/*---------------------------------------------------------------------------*/
/* [set] */

void test_set (void)
{
	/* start test */
	printf("[set "); fflush(stdout);
	fprintf(TESTLOG,"\n[set]\n");

	/* reset counter */
	n_tests_failed = 0;
  
{ /* invalid NULL ptr */
UNUR_PAR   *par = NULL;
   par = NULL; 


unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,72,(unur_arou_set_usedars( par, 1 )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,72,UNUR_ERR_NULL)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,75,(unur_arou_set_darsfactor( par, 1 )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,75,UNUR_ERR_NULL)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,78,(unur_arou_set_cpoints( par, 0, NULL )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,78,UNUR_ERR_NULL)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,81,(unur_arou_set_guidefactor( par, 1. )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,81,UNUR_ERR_NULL)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,84,(unur_arou_set_max_sqhratio( par, 0.95 )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,84,UNUR_ERR_NULL)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,87,(unur_arou_set_max_segments( par, 100 )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,87,UNUR_ERR_NULL)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,90,(unur_arou_set_center( par, 0. )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,90,UNUR_ERR_NULL)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,93,(unur_arou_set_usecenter( par, 1 )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,93,UNUR_ERR_NULL)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,96,(unur_arou_set_verify( par, 1 )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,96,UNUR_ERR_NULL)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,99,(unur_arou_set_pedantic( par, 1 )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,99,UNUR_ERR_NULL)==UNUR_SUCCESS)?0:1;
}

{ /* invalid parameter object */
UNUR_DISTR *distr = NULL;
UNUR_PAR   *par = NULL;
   double fpar[2] = {0.,1.};
   distr = unur_distr_normal(fpar,2);
   par = unur_tdr_new(distr); 


unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,108,(unur_arou_set_usedars( par, 1 )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,108,UNUR_ERR_PAR_INVALID)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,111,(unur_arou_set_darsfactor( par, 1 )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,111,UNUR_ERR_PAR_INVALID)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,114,(unur_arou_set_cpoints( par, 0, NULL )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,114,UNUR_ERR_PAR_INVALID)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,117,(unur_arou_set_guidefactor( par, 1. )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,117,UNUR_ERR_PAR_INVALID)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,120,(unur_arou_set_max_sqhratio( par, 0.95 )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,120,UNUR_ERR_PAR_INVALID)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,123,(unur_arou_set_max_segments( par, 100 )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,123,UNUR_ERR_PAR_INVALID)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,126,(unur_arou_set_center( par, 0. )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,126,UNUR_ERR_PAR_INVALID)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,129,(unur_arou_set_usecenter( par, 1 )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,129,UNUR_ERR_PAR_INVALID)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,132,(unur_arou_set_verify( par, 1 )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,132,UNUR_ERR_PAR_INVALID)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,135,(unur_arou_set_pedantic( par, 1 )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,135,UNUR_ERR_PAR_INVALID)==UNUR_SUCCESS)?0:1;
unur_par_free(par);
unur_distr_free(distr);
}

{ /* invalid parameters */
UNUR_DISTR *distr = NULL;
UNUR_PAR   *par = NULL;
   double stp[] = {1.,0.,1.};
   int n_stp = 3;
   double fpar[2] = {0.,1.};
   distr = unur_distr_normal(fpar,2);
   par = unur_arou_new(distr); 


unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,148,(unur_arou_set_darsfactor( par, -1 )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,148,UNUR_ERR_PAR_SET)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,151,(unur_arou_set_cpoints( par, -1, NULL )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,151,UNUR_ERR_PAR_SET)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,154,(unur_arou_set_cpoints( par, n_stp, stp )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,154,UNUR_ERR_PAR_SET)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,157,(unur_arou_set_guidefactor( par, -1. )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,157,UNUR_ERR_PAR_SET)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,160,(unur_arou_set_max_sqhratio( par, -1. )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,160,UNUR_ERR_PAR_SET)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,163,(unur_arou_set_max_sqhratio( par, 2. )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,163,UNUR_ERR_PAR_SET)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,166,(unur_arou_set_max_segments( par, 0 )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,166,UNUR_ERR_PAR_SET)==UNUR_SUCCESS)?0:1;
unur_par_free(par);
unur_distr_free(distr);
}


	/* test finished */
	test_ok &= (n_tests_failed) ? 0 : 1;
	(n_tests_failed) ? printf(" ==> failed] ") : printf(" ==> ok] ");

#if WITH_DMALLOC
	dmalloc_vmessage("section = set  ================================\n",NULL);
	dmalloc_log_unfreed();
#endif

} /* end of test_set() */

/*---------------------------------------------------------------------------*/
/* [get] */

void test_get (void)
{
	/* start test */
	printf("[get "); fflush(stdout);
	fprintf(TESTLOG,"\n[get]\n");

	/* reset counter */
	n_tests_failed = 0;
  
{ /* invalid generator object */
UNUR_DISTR *distr = NULL;
UNUR_PAR   *par = NULL;
UNUR_GEN   *gen = NULL;
   distr = unur_distr_normal(NULL,0);
   par = unur_tdr_new(distr);
   gen = unur_init(par); 
abort_if_NULL(TESTLOG, 176,    gen );


unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,180,(unur_arou_get_sqhratio(gen)))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,180,UNUR_ERR_GEN_INVALID)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,183,(unur_arou_get_hatarea(gen)))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,183,UNUR_ERR_GEN_INVALID)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,186,(unur_arou_get_squeezearea(gen)))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,186,UNUR_ERR_GEN_INVALID)==UNUR_SUCCESS)?0:1;
unur_distr_free(distr);
unur_free(gen);
}


	/* test finished */
	test_ok &= (n_tests_failed) ? 0 : 1;
	(n_tests_failed) ? printf(" ==> failed] ") : printf(" ==> ok] ");

#if WITH_DMALLOC
	dmalloc_vmessage("section = get  ================================\n",NULL);
	dmalloc_log_unfreed();
#endif

} /* end of test_get() */

/*---------------------------------------------------------------------------*/
/* [chg] */

void test_chg (void)
{
	/* start test */
	printf("[chg "); fflush(stdout);
	fprintf(TESTLOG,"\n[chg]\n");

	/* reset counter */
	n_tests_failed = 0;
  
{ /* invalid generator object */
UNUR_DISTR *distr = NULL;
UNUR_PAR   *par = NULL;
UNUR_GEN   *gen = NULL;
   double fpar[2] = {0.,1.};
   distr = unur_distr_normal(fpar,2);
   par = unur_srou_new(distr);
   unur_set_debug(par,0);
   gen = unur_init( par ); 
abort_if_NULL(TESTLOG, 196,    gen );


unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,200,(unur_arou_chg_verify(gen,1)))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,200,UNUR_ERR_GEN_INVALID)==UNUR_SUCCESS)?0:1;
unur_distr_free(distr);
unur_free(gen);
}


	/* test finished */
	test_ok &= (n_tests_failed) ? 0 : 1;
	(n_tests_failed) ? printf(" ==> failed] ") : printf(" ==> ok] ");

#if WITH_DMALLOC
	dmalloc_vmessage("section = chg  ================================\n",NULL);
	dmalloc_log_unfreed();
#endif

} /* end of test_chg() */

/*---------------------------------------------------------------------------*/
/* [init] */

void test_init (void)
{
	/* start test */
	printf("[init "); fflush(stdout);
	fprintf(TESTLOG,"\n[init]\n");

	/* reset counter */
	n_tests_failed = 0;
  
{ /* invalid NULL ptr */
UNUR_PAR   *par = NULL;
   par = NULL; 


unur_errno = 0;
n_tests_failed += (check_expected_NULL(TESTLOG,211,(unur_init( par )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,211,UNUR_ERR_NULL)==UNUR_SUCCESS)?0:1;
}

{ /* stp out of domain */
UNUR_GEN   *gen = NULL;
UNUR_DISTR *distr = NULL;
UNUR_PAR   *par = NULL;
   double stp[] = {-2.5,-1.,0.,1.,2.5};
   int n_stp = 5;
   gen = NULL;
   distr = unur_distr_normal(NULL,0);
   unur_distr_cont_set_domain(distr,-2.,2.);
   par = unur_arou_new(distr);
   unur_arou_set_cpoints( par, n_stp, stp ); 


unur_errno = 0;
gen = unur_init( par );
n_tests_failed += (check_errorcode(TESTLOG,223,UNUR_ERR_GEN_DATA)==UNUR_SUCCESS)?0:1;
unur_free(gen);
unur_distr_free(distr);
}

{ /* bimodal */
UNUR_DISTR *distr = NULL;
UNUR_PAR   *par = NULL;
   distr = unur_distr_cont_new();
   unur_distr_cont_set_pdf(distr,pdf_bimodal);
   unur_distr_cont_set_dpdf(distr,dpdf_bimodal);
   par = unur_arou_new(distr);
   unur_arou_set_cpoints( par, 30, NULL ); 


unur_errno = 0;
n_tests_failed += (check_expected_NULL(TESTLOG,233,(unur_init( par )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,233,UNUR_ERR_GEN_CONDITION)==UNUR_SUCCESS)?0:1;
unur_distr_free(distr);
}

{ /* negative value of pdf */
UNUR_DISTR *distr = NULL;
UNUR_PAR   *par = NULL;
   distr = unur_distr_cont_new();
   unur_distr_cont_set_pdf(distr,pdf_negative);
   unur_distr_cont_set_dpdf(distr,dpdf_negative);
   par = NULL; 


unur_errno = 0;
par = unur_arou_new(distr);
unur_arou_set_cpoints( par, 30, NULL );
n_tests_failed += (check_expected_NULL(TESTLOG,244,(unur_init( par )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,244,UNUR_ERR_GEN_CONDITION)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
unur_distr_cont_set_domain(distr,-2.,2.);
par = unur_arou_new(distr);
unur_arou_set_cpoints( par, 30, NULL );
n_tests_failed += (check_expected_NULL(TESTLOG,250,(unur_init( par )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,250,UNUR_ERR_GEN_DATA)==UNUR_SUCCESS)?0:1;
unur_distr_free(distr);
}


	/* test finished */
	test_ok &= (n_tests_failed) ? 0 : 1;
	(n_tests_failed) ? printf(" ==> failed] ") : printf(" ==> ok] ");

#if WITH_DMALLOC
	dmalloc_vmessage("section = init  ================================\n",NULL);
	dmalloc_log_unfreed();
#endif

} /* end of test_init() */

/*---------------------------------------------------------------------------*/
/* [reinit] */

void test_reinit (void)
{
	/* start test */
	printf("[reinit "); fflush(stdout);
	fprintf(TESTLOG,"\n[reinit]\n");

	/* reset counter */
	n_tests_failed = 0;
  

	/* test finished */
	test_ok &= (n_tests_failed) ? 0 : 1;
	(n_tests_failed) ? printf(" ==> failed] ") : printf(" ==> ok] ");

#if WITH_DMALLOC
	dmalloc_vmessage("section = reinit  ================================\n",NULL);
	dmalloc_log_unfreed();
#endif

} /* end of test_reinit() */

/*---------------------------------------------------------------------------*/
/* [sample] */

void test_sample (void)
{
	/* start test */
	printf("[sample "); fflush(stdout);
	fprintf(TESTLOG,"\n[sample]\n");

	/* reset counter */
	n_tests_failed = 0;
  
{ /* partial negative value of pdf */
UNUR_DISTR *distr = NULL;
UNUR_PAR   *par = NULL;
UNUR_GEN   *gen = NULL;
   int i;
   double x;
   double stp[] = {-0.9,0.9};
   int n_stp = 2;
   distr = unur_distr_cont_new();
   unur_distr_cont_set_pdf(distr,pdf_partnegative);
   unur_distr_cont_set_dpdf(distr,dpdf_partnegative);
   par = unur_arou_new(distr);
   unur_arou_set_cpoints( par, n_stp, stp );
   unur_arou_set_pedantic( par, 1 );
   gen = unur_init( par ); 
abort_if_NULL(TESTLOG, 270,    gen );


unur_errno = 0;
for (i=0; i<100; i++) { x = unur_sample_cont(gen); }
n_tests_failed += (check_expected_INFINITY(TESTLOG,275,(x))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,275,UNUR_ERR_GEN_CONDITION)==UNUR_SUCCESS)?0:1;
unur_distr_free(distr);
unur_free(gen);
}

{ /* compare clone */
UNUR_DISTR *distr = NULL;
UNUR_PAR   *par = NULL;
UNUR_GEN   *gen = NULL;
   UNUR_GEN *clone;
   distr = unur_distr_normal(NULL,0); 
   par = NULL;
   gen = NULL; 


unur_errno = 0;
/* original generator object */
par = unur_arou_new(distr);
unur_arou_set_max_sqhratio(par,0.);
gen = unur_init(par);
n_tests_failed += (compare_double_sequence_gen_start(TESTLOG,289,gen,COMPARE_SAMPLE_SIZE)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
/* clone */
clone = unur_gen_clone(gen);
unur_free(gen);
gen = clone;
n_tests_failed += (compare_double_sequence_gen(TESTLOG,295,gen,COMPARE_SAMPLE_SIZE)==UNUR_SUCCESS)?0:1;
unur_distr_free(distr);
unur_free(gen);
}

{ /* compare stringparser */
UNUR_DISTR *distr = NULL;
UNUR_PAR   *par = NULL;
UNUR_GEN   *gen = NULL;
   double fpar[10];
   distr = NULL;
   par = NULL;
   gen = NULL; 


unur_errno = 0;
distr = unur_distr_normal(NULL,0); 
par = unur_arou_new(distr);
gen = unur_init(par);
n_tests_failed += (compare_double_sequence_gen_start(TESTLOG,325,gen,COMPARE_SAMPLE_SIZE)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
unur_free(gen); gen = NULL;
unur_distr_free(distr); distr = NULL;
gen = unur_str2gen( "normal & method = arou" );
n_tests_failed += (compare_double_sequence_gen(TESTLOG,330,gen,COMPARE_SAMPLE_SIZE)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
unur_free(gen); gen = NULL;
gen = unur_str2gen( "normal() & method = arou" );
n_tests_failed += (compare_double_sequence_gen(TESTLOG,334,gen,COMPARE_SAMPLE_SIZE)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
unur_free(gen); gen = NULL;
gen = unur_str2gen( "normal(0.,1.) & method = arou" );
n_tests_failed += (compare_double_sequence_gen(TESTLOG,338,gen,COMPARE_SAMPLE_SIZE)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
unur_free(gen); gen = NULL;
gen = unur_str2gen( "normal(0,1) & method = arou" );
n_tests_failed += (compare_double_sequence_gen(TESTLOG,342,gen,COMPARE_SAMPLE_SIZE)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
unur_free(gen); gen = NULL;
gen = unur_str2gen( "distr = normal(0,1) & method = arou" );
n_tests_failed += (compare_double_sequence_gen(TESTLOG,346,gen,COMPARE_SAMPLE_SIZE)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
unur_free(gen); gen = NULL;
fpar[0] = 1.;
fpar[1] = 2.;
distr = unur_distr_normal(fpar,2); 
par = unur_arou_new(distr);
unur_arou_set_usedars(par,1);
gen = unur_init(par);
n_tests_failed += (compare_double_sequence_gen_start(TESTLOG,355,gen,COMPARE_SAMPLE_SIZE)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
unur_free(gen); gen = NULL;
unur_distr_free(distr); distr = NULL;
gen = unur_str2gen( "normal(1,2) & method = arou; usedars" );
n_tests_failed += (compare_double_sequence_gen(TESTLOG,360,gen,COMPARE_SAMPLE_SIZE)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
unur_free(gen); gen = NULL;
fpar[0] = 1.;
fpar[1] = 2.;
distr = unur_distr_normal(fpar,2); 
par = unur_arou_new(distr);
unur_arou_set_usedars(par,1);
unur_arou_set_darsfactor(par,0.1);
gen = unur_init(par);
n_tests_failed += (compare_double_sequence_gen_start(TESTLOG,370,gen,COMPARE_SAMPLE_SIZE)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
unur_free(gen); gen = NULL;
unur_distr_free(distr); distr = NULL;
gen = unur_str2gen( "normal(1,2) & method = arou; usedars; darsfactor=0.1" );
n_tests_failed += (compare_double_sequence_gen(TESTLOG,375,gen,COMPARE_SAMPLE_SIZE)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
unur_free(gen); gen = NULL;
fpar[0] = 1.;
fpar[1] = 2.;
distr = unur_distr_normal(fpar,2);
unur_distr_cont_set_domain(distr,0,2.); 
par = unur_arou_new(distr);
gen = unur_init(par);
n_tests_failed += (compare_double_sequence_gen_start(TESTLOG,384,gen,COMPARE_SAMPLE_SIZE)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
unur_free(gen); gen = NULL;
unur_distr_free(distr); distr = NULL;
gen = unur_str2gen( "normal(1,2); domain = 0, 2 & method = arou" );
n_tests_failed += (compare_double_sequence_gen(TESTLOG,389,gen,COMPARE_SAMPLE_SIZE)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
unur_free(gen); gen = NULL;
gen = unur_str2gen( "normal(1,2); domain = (0,2) & method = arou" );
n_tests_failed += (compare_double_sequence_gen(TESTLOG,393,gen,COMPARE_SAMPLE_SIZE)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
unur_free(gen); gen = NULL;
distr = unur_distr_normal(NULL,0); 
par = unur_arou_new(distr);
fpar[0] = -2;
fpar[1] = -1.5;
fpar[2] = -1;
fpar[3] = -0.5;
fpar[4] = 0;
fpar[5] = 0.5;
fpar[6] = 1;
fpar[7] = 1.5;
fpar[8] = 2;
unur_arou_set_cpoints(par,9,fpar);
gen = unur_init(par);
n_tests_failed += (compare_double_sequence_gen_start(TESTLOG,409,gen,COMPARE_SAMPLE_SIZE)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
unur_free(gen); gen = NULL;
unur_distr_free(distr); distr = NULL;
gen = unur_str2gen( "normal() & \
  method = arou; cpoints = (-2,-1.5,-1,-0.5,0,0.5,1,1.5,2)" );
n_tests_failed += (compare_double_sequence_gen(TESTLOG,415,gen,COMPARE_SAMPLE_SIZE)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
unur_free(gen); gen = NULL;
distr = unur_distr_normal(NULL,0); 
par = unur_arou_new(distr);
unur_arou_set_center(par,0);
unur_arou_set_cpoints(par,20,NULL);
unur_arou_set_guidefactor(par,1.);
unur_arou_set_max_segments(par,40);
unur_arou_set_max_sqhratio(par,0.5);
unur_arou_set_pedantic(par,FALSE);
unur_arou_set_usecenter(par,TRUE);
unur_arou_set_verify(par,TRUE);
gen = unur_init(par);
n_tests_failed += (compare_double_sequence_gen_start(TESTLOG,429,gen,COMPARE_SAMPLE_SIZE)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
unur_free(gen); gen = NULL;
unur_distr_free(distr); distr = NULL;
gen = unur_str2gen( "normal() & \
  method = arou; \
  center = 0; cpoints = 20; guidefactor = 1.; max_segments = 40; \
  max_sqhratio = 0.5; pedantic = off; usecenter = true; verify = on" );
n_tests_failed += (compare_double_sequence_gen(TESTLOG,437,gen,COMPARE_SAMPLE_SIZE)==UNUR_SUCCESS)?0:1;
unur_distr_free(distr);
unur_free(gen);
}


	/* test finished */
	test_ok &= (n_tests_failed) ? 0 : 1;
	(n_tests_failed) ? printf(" ==> failed] ") : printf(" ==> ok] ");

#if WITH_DMALLOC
	dmalloc_vmessage("section = sample  ================================\n",NULL);
	dmalloc_log_unfreed();
#endif

} /* end of test_sample() */

/*---------------------------------------------------------------------------*/
/* [validate] */

/*---------------------------------------------------------------------------*/

/* [validate] */

void test_validate (void)
{
	UNUR_DISTR *distr[33];
	UNUR_PAR *par;
	UNUR_GEN *gen;
	int n_tests_failed = 0;
	int rcode;
	double *darray;
	double fpm[10];

	rcode = 0;

	/* start test */
	printf("[validate "); fflush(stdout);
	fprintf(TESTLOG,"\n[validate]\n");

	/* reset counter */
	n_tests_failed = 0;


/* distributions: 33 */
{
fpm[0] = 1.;
fpm[1] = 2.;
distr[0] = unur_distr_beta(fpm,2);
}

{
fpm[0] = 2.;
fpm[1] = 1.;
distr[32] = unur_distr_beta(fpm,2);
}

{
fpm[0] = 1.;
fpm[1] = 5.;
distr[1] = unur_distr_beta(fpm,2);
}

{
fpm[0] = 1.;
fpm[1] = 100.;
distr[2] = unur_distr_beta(fpm,2);
}

{
fpm[0] = 2.;
fpm[1] = 5.;
distr[30] = unur_distr_beta(fpm,2);
}

{
fpm[0] = 5.;
fpm[1] = 2.;
distr[31] = unur_distr_beta(fpm,2);
}

{
fpm[0] = 3.;
fpm[1] = 4.;
distr[3] = unur_distr_beta(fpm,2);
}

{
fpm[0] = 5.;
fpm[1] = 100.;
distr[4] = unur_distr_beta(fpm,2);
}

{
fpm[0] = 500.;
fpm[1] = 300.;
distr[5] = unur_distr_beta(fpm,2);
}

{
fpm[0] = 5.;
fpm[1] = 10.;
fpm[2] = -3.;
fpm[3] = 15.;
distr[6] = unur_distr_beta(fpm,4);
}

{
distr[7] = unur_distr_cauchy(NULL,0);
}

{
fpm[0] = 1.;
fpm[1] = 20.;
distr[8] = unur_distr_cauchy(fpm,2);
}

{
distr[24] = unur_distr_exponential(NULL,0);
}

{
fpm[0] = 30.;
fpm[1] = -5.;
distr[25] = unur_distr_exponential(fpm,2);
}

{
fpm[0] = 1.;
distr[9] = unur_distr_gamma(fpm,1);
}

{
fpm[0] = 2.;
distr[10] = unur_distr_gamma(fpm,1);
}

{
fpm[0] = 3.;
distr[11] = unur_distr_gamma(fpm,1);
}

{
fpm[0] = 10.;
distr[12] = unur_distr_gamma(fpm,1);
}

{
fpm[0] = 1000.;
distr[13] = unur_distr_gamma(fpm,1);
}

{
fpm[0] = 5.;
fpm[1] = 1000.;
distr[14] = unur_distr_gamma(fpm,2);
}

{
fpm[0] = 5.;
fpm[1] = 1.e-5;
distr[15] = unur_distr_gamma(fpm,2);
}

{
fpm[0] = 5.;
fpm[1] = 10.;
fpm[2] = 1000;
distr[16] = unur_distr_gamma(fpm,3);
}

{
distr[26] = unur_distr_laplace(NULL,0);
}

{
fpm[0] = -10.;
fpm[1] = 100.;
distr[27] = unur_distr_laplace(fpm,2);
}

{
distr[17] = unur_distr_normal(NULL,0);
}

{
fpm[0] = 1.;
fpm[1] = 1.e-5;
distr[18] = unur_distr_normal(fpm,2);
}

{
fpm[0] = 0.;
fpm[1] = 1.e+5;
distr[19] = unur_distr_normal(fpm,2);
}

{
distr[20] = unur_distr_uniform(NULL,0);
}

{
fpm[0] = 1.;
fpm[1] = 20.;
distr[21] = unur_distr_uniform(fpm,2);
}

{
distr[28] = unur_distr_cont_new();
unur_distr_cont_set_pdf(distr[28],pdf_sqrtlin);
unur_distr_cont_set_dpdf(distr[28],dpdf_sqrtlin);
unur_distr_cont_set_cdf(distr[28],cdf_sqrtlin);
unur_distr_set_name(distr[28],"sqrtlin");
}

{
distr[29] = unur_distr_cont_new();
unur_distr_cont_set_pdf(distr[29],pdf_sqrtlinshft);
unur_distr_cont_set_dpdf(distr[29],dpdf_sqrtlinshft);
unur_distr_cont_set_cdf(distr[29],cdf_sqrtlinshft);
unur_distr_set_name(distr[29],"sqrtlin");
}

{
distr[22] = unur_distr_cauchy(NULL,0);
unur_distr_cont_set_domain(distr[22],0.1,1.);
unur_distr_cont_upd_mode(distr[22]);
unur_distr_cont_upd_pdfarea(distr[22]);
}

{
fpm[0] = 3.;
fpm[1] = 4.;
distr[23] = unur_distr_beta(fpm,2);
unur_distr_cont_set_domain(distr[23],-2.,5.);
}

	printf("\n(chi^2) "); fflush(stdout);

/* chi^2 tests: 99 */

	unur_set_default_debug(~UNUR_DEBUG_SAMPLE);
	fprintf( TESTLOG,"\nChi^2 Test:\n");

/* distribution [0] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[0]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[0],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[0]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[0],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[0]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[0],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [32] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[32]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[32],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[32]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[32],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[32]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[32],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [1] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[1]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[1],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[1]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[1],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[1]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[1],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [2] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[2]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[2],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[2]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[2],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[2]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[2],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [30] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[30]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[30],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[30]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[30],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[30]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[30],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [31] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[31]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[31],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[31]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[31],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[31]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[31],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [3] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[3]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[3],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[3]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[3],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[3]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[3],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [4] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[4]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[4],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[4]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[4],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[4]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[4],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [5] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[5]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[5],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[5]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[5],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[5]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[5],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [6] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[6]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[6],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[6]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[6],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[6]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[6],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [24] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[24]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[24],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[24]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[24],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[24]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[24],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [7] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[7]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[7],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[7]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[7],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[7]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[7],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [8] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[8]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[8],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[8]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[8],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[8]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[8],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [9] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[9]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[9],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[9]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[9],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[9]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[9],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [10] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[10]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[10],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[10]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[10],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[10]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[10],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [11] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[11]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[11],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[11]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[11],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[11]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[11],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [12] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[12]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[12],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[12]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[12],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[12]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[12],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [13] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[13]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[13],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[13]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[13],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[13]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[13],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [14] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[14]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[14],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[14]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[14],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[14]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[14],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [15] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[15]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[15],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[15]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[15],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[15]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[15],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [16] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[16]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[16],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[16]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[16],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[16]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[16],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [26] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[26]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[26],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[26]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[26],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[26]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[26],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [27] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[27]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[27],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[27]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[27],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[27]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[27],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [17] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[17]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[17],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[17]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[17],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[17]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[17],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [18] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[18]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[18],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[18]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[18],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

/* distribution [19] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[19]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[19],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[19]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[19],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[19]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[19],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [20] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[20]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[20],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[20]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[20],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[20]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[20],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [21] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[21]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[21],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[21]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[21],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[21]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[21],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [22] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[22]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[22],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[22]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[22],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[22]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[22],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [23] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[23]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[23],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[23]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[23],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[23]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[23],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("\n(verify hat) "); fflush(stdout);

/* verify hat tests: 99 */

	unur_set_default_debug(~UNUR_DEBUG_SAMPLE);
	fprintf( TESTLOG,"\nVerify Hat Test (squeeze <= PDF <= hat):\n");

/* distribution [0] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[0]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[0],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[0]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[0],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[0]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[0],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [32] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[32]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[32],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[32]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[32],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[32]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[32],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [1] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[1]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[1],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[1]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[1],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[1]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[1],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [2] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[2]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[2],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[2]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[2],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[2]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[2],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [30] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[30]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[30],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[30]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[30],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[30]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[30],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [31] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[31]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[31],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[31]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[31],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[31]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[31],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [3] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[3]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[3],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[3]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[3],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[3]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[3],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [4] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[4]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[4],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[4]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[4],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[4]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[4],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [5] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[5]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[5],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[5]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[5],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[5]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[5],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [6] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[6]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[6],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[6]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[6],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[6]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[6],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [24] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[24]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[24],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[24]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[24],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[24]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[24],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [7] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[7]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[7],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[7]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[7],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[7]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[7],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [8] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[8]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[8],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[8]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[8],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[8]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[8],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [9] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[9]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[9],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[9]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[9],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[9]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[9],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [10] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[10]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[10],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[10]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[10],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[10]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[10],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [11] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[11]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[11],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[11]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[11],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[11]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[11],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [12] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[12]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[12],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[12]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[12],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[12]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[12],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [13] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[13]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[13],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[13]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[13],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[13]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[13],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [14] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[14]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[14],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[14]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[14],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[14]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[14],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [15] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[15]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[15],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[15]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[15],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[15]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[15],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [16] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[16]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[16],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[16]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[16],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[16]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[16],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [26] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[26]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[26],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[26]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[26],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[26]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[26],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [27] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[27]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[27],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[27]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[27],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[27]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[27],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [17] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[17]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[17],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[17]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[17],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[17]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[17],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [18] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[18]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[18],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[18]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[18],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[18]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[18],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [19] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[19]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[19],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[19]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[19],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[19]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[19],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [20] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[20]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[20],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[20]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[20],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[20]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[20],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [21] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[21]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[21],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[21]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[21],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[21]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[21],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [22] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[22]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[22],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[22]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[22],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[22]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[22],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [23] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[23]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_usedars(par,0);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[23],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[23]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_usedars(par,1);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[23],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[23]);
	unur_errno = 0;
par = unur_arou_new(distr_localcopy);
	unur_arou_set_pedantic(par,0);
unur_arou_set_cpoints( par, 8, NULL );
unur_arou_set_max_sqhratio(par,0.5);
	gen = unur_init(par);
	if (gen) unur_arou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[23],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);


/* free distributions */
	unur_distr_free(distr[0]);
	unur_distr_free(distr[1]);
	unur_distr_free(distr[2]);
	unur_distr_free(distr[3]);
	unur_distr_free(distr[4]);
	unur_distr_free(distr[5]);
	unur_distr_free(distr[6]);
	unur_distr_free(distr[7]);
	unur_distr_free(distr[8]);
	unur_distr_free(distr[9]);
	unur_distr_free(distr[10]);
	unur_distr_free(distr[11]);
	unur_distr_free(distr[12]);
	unur_distr_free(distr[13]);
	unur_distr_free(distr[14]);
	unur_distr_free(distr[15]);
	unur_distr_free(distr[16]);
	unur_distr_free(distr[17]);
	unur_distr_free(distr[18]);
	unur_distr_free(distr[19]);
	unur_distr_free(distr[20]);
	unur_distr_free(distr[21]);
	unur_distr_free(distr[22]);
	unur_distr_free(distr[23]);
	unur_distr_free(distr[24]);
	unur_distr_free(distr[25]);
	unur_distr_free(distr[26]);
	unur_distr_free(distr[27]);
	unur_distr_free(distr[28]);
	unur_distr_free(distr[29]);
	unur_distr_free(distr[30]);
	unur_distr_free(distr[31]);
	unur_distr_free(distr[32]);
#if WITH_DMALLOC
	dmalloc_vmessage("section = validate  ================================\n","");
	dmalloc_log_unfreed();
#endif


	/* test finished */
	test_ok &= (n_tests_failed>CHI2_FAILURES_TOLERATED) ? 0 : 1;
	/* we accept CHI2_FAILURES_TOLERATED failures */
	(n_tests_failed>CHI2_FAILURES_TOLERATED) ? printf(" ==> failed] ") : printf(" ==> ok] ");

	/* prevent compiler from making useless annoying warnings */
	distr[0] = NULL;
	par = NULL;
	gen = NULL;
	darray = NULL;
	fpm[0] = 0.;

} /* end of test_validate */


/*---------------------------------------------------------------------------*/
/* run generator in verifying mode */

void run_verify_generator( FILE *LOG, int line, UNUR_PAR *par )
{
	UNUR_GEN *gen;
	int i;

	/* switch to verifying mode */
	unur_arou_set_verify(par,1);

	/* initialize generator */
	gen = unur_init( par ); abort_if_NULL(LOG, line, gen);

	/* run generator */
	for (i=0; i<VIOLATE_SAMPLE_SIZE; i++)
		unur_sample_cont(gen);

	/* destroy generator */
	unur_free(gen); 

} /* end of run_verify_generator() */


/*---------------------------------------------------------------------------*/

int main()
{ 
	/* open log file for unuran and set output stream for unuran messages */
	UNURANLOG = fopen( "t_arou_unuran.log","w" );
	abort_if_NULL( stderr,-1, UNURANLOG );
	unur_set_stream( UNURANLOG );

	/* open log file for testing */
	TESTLOG = fopen( "t_arou_test.log","w" );
	abort_if_NULL( stderr,-1, TESTLOG );

	/* write header into log file */
  	{
		time_t started;  
		fprintf(TESTLOG,"\nUNURAN - Universal Non-Uniform RANdom number generator\n\n");
		if (time( &started ) != -1)
			fprintf(TESTLOG,"%s",ctime(&started));
		fprintf(TESTLOG,"\n====================================================\n\n");
	}

        /* seed build-in uniform generators */
        unur_urng_MRG31k3p_seed(989783);
	unur_urng_fish_seed(989783);
	unur_urng_mstd_seed(989783);

	/* seed uniform random number generator */
#if UNUR_URNG_TYPE == UNUR_URNG_GENERIC
/*
	if (unur_urng_seed(NULL, 989783) != UNUR_SUCCESS) {
	  fprintf(stderr,"WARNING: Seed could not be set at random\n");
	}  
*/
#elif UNUR_URNG_TYPE == UNUR_URNG_PRNG
	unur_set_default_urng(prng_new("mt19937(989783)"));
#elif UNUR_URNG_TYPE == UNUR_URNG_RNGSTREAM
	{
	    unsigned long seed[6] = {989783,989783,989783,989783,989783,989783};
	    RngStream_SetPackageSeed(seed);
	}
#endif  /* UNUR_URNG_TYPE */

	/* set default debugging flag */
	unur_set_default_debug(UNUR_DEBUG_ALL);

	/* start test */
	printf("arou: ");

	/* run tests */
test_new();
test_set();
test_get();
test_chg();
test_init();
test_reinit();
test_sample();
test_validate();


	/* test finished */
	printf("\n");  fflush(stdout);

	/* close log files */
	fprintf(TESTLOG,"\n====================================================\n\n");
	if (test_ok)
		fprintf(TESTLOG,"All tests PASSED.\n");
	else
		fprintf(TESTLOG,"Test(s) FAILED.\n");

	fclose(UNURANLOG);
	fclose(TESTLOG);

	/* free memory */
        compare_free_memory();

	/* exit */
	exit( (test_ok) ? EXIT_SUCCESS : EXIT_FAILURE );

} /* end of main */

