/*
	file automatically generated by make_test_files.pl
	Thu Jan  5 10:45:31 2006
*/

/*****************************************************************************
 *                                                                           *
 *          UNURAN -- Universal Non-Uniform Random number generator          *
 *                                                                           *
 *****************************************************************************/
    
/**
 ** Tests for VNROU
 **/
    
/*---------------------------------------------------------------------------*/
#include "testunuran.h"
/*---------------------------------------------------------------------------*/

/*---------------------------------------------------------------------------*/
/* global variables                                                          */

static FILE *TESTLOG;               /* test log file                         */
static FILE *UNURANLOG;             /* unuran log file                       */

static int test_ok = TRUE;          /* all tests ok (boolean)                */
static int n_tests_failed;          /* number of failed tests                */

/*---------------------------------------------------------------------------*/

void run_verify_generator( FILE *LOG, int line, UNUR_PAR *par );

int unur_vnrou_set_verify( UNUR_PAR *par, int );

/*---------------------------------------------------------------------------*/



/* prototypes */

int unur_vnrou_set_pedantic( UNUR_PAR *par, int pedantic );

#define COMPARE_SAMPLE_SIZE   (10000)
#define VIOLATE_SAMPLE_SIZE   (20)




/*---------------------------------------------------------------------------*/

#ifndef CHI2_FAILURES_TOLERATED
#  define CHI2_FAILURES_TOLERATED DEFAULT_CHI2_FAILURES_TOLERATED
#endif

/*---------------------------------------------------------------------------*/
/* [verbatim] */



/* dummy function */
int unur_vnrou_set_pedantic( UNUR_PAR *par, int pedantic )
{ return 1; }

/*---------------------------------------------------------------------------*/
/* [new] */

void test_new (void)
{
	/* start test */
	printf("[new "); fflush(stdout);
	fprintf(TESTLOG,"\n[new]\n");

	/* reset counter */
	n_tests_failed = 0;
  
{ /* invalid NULL ptr */
UNUR_DISTR *distr = NULL;
   distr = NULL; 


unur_errno = 0;
n_tests_failed += (check_expected_NULL(TESTLOG,28,(unur_vnrou_new( distr )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,28,UNUR_ERR_NULL)==UNUR_SUCCESS)?0:1;
unur_distr_free(distr);
}

{ /* invalid distribution type */
UNUR_DISTR *distr = NULL;
   distr = unur_distr_discr_new(); 


unur_errno = 0;
n_tests_failed += (check_expected_NULL(TESTLOG,35,(unur_vnrou_new( distr )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,35,UNUR_ERR_DISTR_INVALID)==UNUR_SUCCESS)?0:1;
unur_distr_free(distr);
}


	/* test finished */
	test_ok &= (n_tests_failed) ? 0 : 1;
	(n_tests_failed) ? printf(" ==> failed] ") : printf(" ==> ok] ");

#if WITH_DMALLOC
	dmalloc_vmessage("section = new  ================================\n",NULL);
	dmalloc_log_unfreed();
#endif

} /* end of test_new() */

/*---------------------------------------------------------------------------*/
/* [set] */

void test_set (void)
{
	/* start test */
	printf("[set "); fflush(stdout);
	fprintf(TESTLOG,"\n[set]\n");

	/* reset counter */
	n_tests_failed = 0;
  
{ /* invalid NULL ptr */
UNUR_PAR   *par = NULL;
   par = NULL; 


unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,46,(unur_vnrou_set_u( par, NULL, NULL )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,46,UNUR_ERR_NULL)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,49,(unur_vnrou_set_v( par, 1. )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,49,UNUR_ERR_NULL)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,52,(unur_vnrou_set_r( par, 1. )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,52,UNUR_ERR_NULL)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,55,(unur_vnrou_set_verify( par, 1)))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,55,UNUR_ERR_NULL)==UNUR_SUCCESS)?0:1;
}

{ /* invalid parameter object */
UNUR_DISTR *distr = NULL;
UNUR_PAR   *par = NULL;
   double fpar[2] = {0.,1.};
   distr = unur_distr_normal(fpar,2);
   par = unur_arou_new(distr); 


unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,64,(unur_vnrou_set_u( par, NULL, NULL )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,64,UNUR_ERR_PAR_INVALID)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,67,(unur_vnrou_set_v( par, 1. )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,67,UNUR_ERR_PAR_INVALID)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,70,(unur_vnrou_set_r( par, 1. )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,70,UNUR_ERR_PAR_INVALID)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,73,(unur_vnrou_set_verify( par, 1)))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,73,UNUR_ERR_PAR_INVALID)==UNUR_SUCCESS)?0:1;
unur_par_free(par);
unur_distr_free(distr);
}

{ /* invalid parameters */
UNUR_DISTR *distr = NULL;
UNUR_PAR   *par = NULL;
   const int dim = 3;
   double mean[] = {1.,2.,3.};
   double covar[] = { 2., 2., 1.,   2., 4., 3.,   1., 3., 3. };
   double umin[] = {1.,1.,1.};
   double umax[] = {2.,1.,2.};
   distr = unur_distr_multinormal( dim, mean, covar );
   par = unur_vnrou_new(distr); 


unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,87,(unur_vnrou_set_u( par, NULL, NULL )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,87,UNUR_ERR_NULL)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,90,(unur_vnrou_set_u( par, umin, umax )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,90,UNUR_ERR_PAR_SET)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,93,(unur_vnrou_set_v( par, -1. )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,93,UNUR_ERR_PAR_SET)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,96,(unur_vnrou_set_v( par, 0. )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,96,UNUR_ERR_PAR_SET)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
unur_vnrou_set_r( par, 0. );
n_tests_failed += (check_errorcode(TESTLOG,99,UNUR_ERR_PAR_SET)==UNUR_SUCCESS)?0:1;
unur_par_free(par);
unur_distr_free(distr);
}


	/* test finished */
	test_ok &= (n_tests_failed) ? 0 : 1;
	(n_tests_failed) ? printf(" ==> failed] ") : printf(" ==> ok] ");

#if WITH_DMALLOC
	dmalloc_vmessage("section = set  ================================\n",NULL);
	dmalloc_log_unfreed();
#endif

} /* end of test_set() */

/*---------------------------------------------------------------------------*/
/* [get] */

void test_get (void)
{
	/* start test */
	printf("[get "); fflush(stdout);
	fprintf(TESTLOG,"\n[get]\n");

	/* reset counter */
	n_tests_failed = 0;
  
{ /* invalid NULL ptr */
UNUR_GEN   *gen = NULL;
	gen = NULL; 


unur_errno = 0;
n_tests_failed += (check_expected_INFINITY(TESTLOG,112,(unur_vnrou_get_volumehat( gen )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,112,UNUR_ERR_NULL)==UNUR_SUCCESS)?0:1;
unur_free(gen);
}

{ /* invalid generator object */
UNUR_DISTR *distr = NULL;
UNUR_PAR   *par = NULL;
UNUR_GEN   *gen = NULL;
   distr = unur_distr_normal(NULL,0);
   par = unur_arou_new(distr);
   gen = unur_init(par); 
abort_if_NULL(TESTLOG, 116,    gen );


unur_errno = 0;
n_tests_failed += (check_expected_INFINITY(TESTLOG,120,(unur_vnrou_get_volumehat( gen )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,120,UNUR_ERR_GEN_INVALID)==UNUR_SUCCESS)?0:1;
unur_distr_free(distr);
unur_free(gen);
}


	/* test finished */
	test_ok &= (n_tests_failed) ? 0 : 1;
	(n_tests_failed) ? printf(" ==> failed] ") : printf(" ==> ok] ");

#if WITH_DMALLOC
	dmalloc_vmessage("section = get  ================================\n",NULL);
	dmalloc_log_unfreed();
#endif

} /* end of test_get() */

/*---------------------------------------------------------------------------*/
/* [chg] */

void test_chg (void)
{
	/* start test */
	printf("[chg "); fflush(stdout);
	fprintf(TESTLOG,"\n[chg]\n");

	/* reset counter */
	n_tests_failed = 0;
  
{ /* invalid generator object */
UNUR_DISTR *distr = NULL;
UNUR_PAR   *par = NULL;
UNUR_GEN   *gen = NULL;
   distr = unur_distr_normal(NULL,0);
   par = unur_arou_new(distr);
   unur_set_debug(par,0);
   gen = unur_init( par ); 
abort_if_NULL(TESTLOG, 129,    gen );


unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,133,(unur_vnrou_chg_verify(gen,1)))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,133,UNUR_ERR_GEN_INVALID)==UNUR_SUCCESS)?0:1;
unur_distr_free(distr);
unur_free(gen);
}


	/* test finished */
	test_ok &= (n_tests_failed) ? 0 : 1;
	(n_tests_failed) ? printf(" ==> failed] ") : printf(" ==> ok] ");

#if WITH_DMALLOC
	dmalloc_vmessage("section = chg  ================================\n",NULL);
	dmalloc_log_unfreed();
#endif

} /* end of test_chg() */

/*---------------------------------------------------------------------------*/
/* [init] */

void test_init (void)
{
	/* start test */
	printf("[init "); fflush(stdout);
	fprintf(TESTLOG,"\n[init]\n");

	/* reset counter */
	n_tests_failed = 0;
  

	/* test finished */
	test_ok &= (n_tests_failed) ? 0 : 1;
	(n_tests_failed) ? printf(" ==> failed] ") : printf(" ==> ok] ");

#if WITH_DMALLOC
	dmalloc_vmessage("section = init  ================================\n",NULL);
	dmalloc_log_unfreed();
#endif

} /* end of test_init() */

/*---------------------------------------------------------------------------*/
/* [reinit] */

void test_reinit (void)
{
	/* start test */
	printf("[reinit "); fflush(stdout);
	fprintf(TESTLOG,"\n[reinit]\n");

	/* reset counter */
	n_tests_failed = 0;
  

	/* test finished */
	test_ok &= (n_tests_failed) ? 0 : 1;
	(n_tests_failed) ? printf(" ==> failed] ") : printf(" ==> ok] ");

#if WITH_DMALLOC
	dmalloc_vmessage("section = reinit  ================================\n",NULL);
	dmalloc_log_unfreed();
#endif

} /* end of test_reinit() */

/*---------------------------------------------------------------------------*/
/* [sample] */

void test_sample (void)
{
	/* start test */
	printf("[sample "); fflush(stdout);
	fprintf(TESTLOG,"\n[sample]\n");

	/* reset counter */
	n_tests_failed = 0;
  
{ /* compare */
UNUR_DISTR *distr = NULL;
UNUR_PAR   *par = NULL;
UNUR_GEN   *gen = NULL;
   const int dim = 3;
   double mean[] = {1.,2.,3.};
   double covar[] = { 2., 2., 1.,   2., 4., 3.,   1., 3., 3. };
   distr = unur_distr_multinormal( dim, mean, covar );
   par = unur_vnrou_new(distr);
   gen = unur_init( par ); 
abort_if_NULL(TESTLOG, 153,    gen );


unur_errno = 0;
;
n_tests_failed += (compare_cvec_sequence_gen_start(TESTLOG,157,gen,COMPARE_SAMPLE_SIZE)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
unur_free(gen);
par = unur_vnrou_new(distr);
unur_vnrou_set_verify(par,1);
gen = unur_init( par );
n_tests_failed += (compare_cvec_sequence_gen(TESTLOG,164,gen,COMPARE_SAMPLE_SIZE)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
unur_free(gen);
par = unur_vnrou_new(distr);
unur_vnrou_set_r(par,0.5);
gen = unur_init( par );
n_tests_failed += (compare_cvec_sequence_gen_start(TESTLOG,172,gen,COMPARE_SAMPLE_SIZE)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
unur_free(gen);
par = unur_vnrou_new(distr);
unur_vnrou_set_r(par,0.5);
unur_vnrou_set_verify(par,1);
gen = unur_init( par );
n_tests_failed += (compare_cvec_sequence_gen(TESTLOG,180,gen,COMPARE_SAMPLE_SIZE)==UNUR_SUCCESS)?0:1;
unur_distr_free(distr);
unur_free(gen);
}

{ /* compare 1dim */
UNUR_DISTR *distr = NULL;
UNUR_PAR   *par = NULL;
UNUR_GEN   *gen = NULL;
   const int dim = 1;
   double mean[] = {1.};
   double covar[] = {2.};
   distr = unur_distr_multinormal( dim, mean, covar );
   par = unur_vnrou_new(distr);
   gen = unur_init( par ); 
abort_if_NULL(TESTLOG, 188,    gen );


unur_errno = 0;
;
n_tests_failed += (compare_cvec_sequence_gen_start(TESTLOG,192,gen,COMPARE_SAMPLE_SIZE)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
unur_free(gen);
par = unur_vnrou_new(distr);
unur_vnrou_set_verify(par,1);
gen = unur_init( par );
n_tests_failed += (compare_cvec_sequence_gen(TESTLOG,199,gen,COMPARE_SAMPLE_SIZE)==UNUR_SUCCESS)?0:1;
unur_distr_free(distr);
unur_free(gen);
}

{ /* compare clone */
UNUR_DISTR *distr = NULL;
UNUR_PAR   *par = NULL;
UNUR_GEN   *gen = NULL;
   const int dim = 3;
   double mean[] = {1.,2.,3.};
   double covar[] = { 2., 2., 1.,   2., 4., 3.,   1., 3., 3. };
   UNUR_GEN *clone;
   distr = unur_distr_multinormal( dim, mean, covar );
   par = unur_vnrou_new(distr);
   gen = unur_init( par ); 
abort_if_NULL(TESTLOG, 208,    gen );


unur_errno = 0;
/* normal distribution */;
n_tests_failed += (compare_cvec_sequence_gen_start(TESTLOG,212,gen,COMPARE_SAMPLE_SIZE)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
/* clone */
clone = unur_gen_clone(gen);
unur_free(gen);
gen = clone;
n_tests_failed += (compare_cvec_sequence_gen(TESTLOG,218,gen,COMPARE_SAMPLE_SIZE)==UNUR_SUCCESS)?0:1;
unur_distr_free(distr);
unur_free(gen);
}

{ /* compare clone 1dim */
UNUR_DISTR *distr = NULL;
UNUR_PAR   *par = NULL;
UNUR_GEN   *gen = NULL;
   const int dim = 1;
   double mean[] = {1.};
   double covar[] = {2.};
   UNUR_GEN *clone;
   distr = unur_distr_multinormal( dim, mean, covar );
   par = unur_vnrou_new(distr);
   gen = unur_init( par ); 
abort_if_NULL(TESTLOG, 228,    gen );


unur_errno = 0;
/* normal distribution */;
n_tests_failed += (compare_cvec_sequence_gen_start(TESTLOG,232,gen,COMPARE_SAMPLE_SIZE)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
/* clone */
clone = unur_gen_clone(gen);
unur_free(gen);
gen = clone;
n_tests_failed += (compare_cvec_sequence_gen(TESTLOG,238,gen,COMPARE_SAMPLE_SIZE)==UNUR_SUCCESS)?0:1;
unur_distr_free(distr);
unur_free(gen);
}


	/* test finished */
	test_ok &= (n_tests_failed) ? 0 : 1;
	(n_tests_failed) ? printf(" ==> failed] ") : printf(" ==> ok] ");

#if WITH_DMALLOC
	dmalloc_vmessage("section = sample  ================================\n",NULL);
	dmalloc_log_unfreed();
#endif

} /* end of test_sample() */

/*---------------------------------------------------------------------------*/
/* [validate] */

/*---------------------------------------------------------------------------*/

/* [validate] */

void test_validate (void)
{
	UNUR_DISTR *distr[31];
	UNUR_PAR *par;
	UNUR_GEN *gen;
	int n_tests_failed = 0;
	int rcode;
	double *darray;
	double fpm[10];

	rcode = 0;

	/* start test */
	printf("[validate "); fflush(stdout);
	fprintf(TESTLOG,"\n[validate]\n");

	/* reset counter */
	n_tests_failed = 0;


/* distributions: 31 */
{
distr[0] = unur_distr_multinormal(3,NULL,NULL);
}

{
double mean[]  = { 1., 2., 3. };
double covar[] = { 2., 2., 1.,   2., 4., 3.,   1., 3., 3. };
distr[1] = unur_distr_multinormal(3,mean,covar);
}

{
#define dim (2)
int i;
double mean[dim], covar[dim*dim];
UNUR_DISTR *covar_distr;
UNUR_GEN *covar_gen;
UNUR_GEN *mean_gen;
covar_distr = unur_distr_correlation(dim);
covar_gen = unur_init(unur_mcorr_new(covar_distr));
mean_gen = unur_str2gen("normal(5,1)");
for (i=0; i<dim; i++) 
   mean[i] = unur_sample_cont(mean_gen);
do { 
   unur_sample_matr(covar_gen,covar);
   distr[2] = unur_distr_multinormal(dim,mean,covar); 
} while (distr[2]==NULL);
unur_distr_free(covar_distr);
unur_free(covar_gen);
unur_free(mean_gen); 
#undef dim
}

{
#define dim (3)
int i;
double mean[dim], covar[dim*dim];
UNUR_DISTR *covar_distr;
UNUR_GEN *covar_gen;
UNUR_GEN *mean_gen;
covar_distr = unur_distr_correlation(dim);
covar_gen = unur_init(unur_mcorr_new(covar_distr));
mean_gen = unur_str2gen("normal(5,1)");
for (i=0; i<dim; i++) 
   mean[i] = unur_sample_cont(mean_gen);
do { 
   unur_sample_matr(covar_gen,covar);
   distr[3] = unur_distr_multinormal(dim,mean,covar); 
} while (distr[3]==NULL);
unur_distr_free(covar_distr);
unur_free(covar_gen);
unur_free(mean_gen); 
#undef dim
}

{
double mean[]  = { -1., -2., -3. };
double covar[] = { 2., 2., 1.,   2., 4., 3.,   1., 3., 3. };
distr[4] = unur_distr_multinormal(3,mean,covar);
unur_distr_cvec_set_center(distr[4],NULL);
}

{
distr[5] = unur_distr_multinormal(1,NULL,NULL);
}

{
double mean[]  = { -1. };
double covar[] = { 2. };
distr[6] = unur_distr_multinormal(1,mean,covar);
unur_distr_cvec_set_center(distr[6],NULL);
}

{
distr[7] = unur_distr_multinormal_ar1(2,NULL,0.5);
}

{
distr[8] = unur_distr_multinormal_ar1(3,NULL,0.5);
}

{
distr[9] = unur_distr_multinormal_ar1(4,NULL,0.5);
}

{
distr[10] = unur_distr_multinormal_ar1(5,NULL,0.5);
}

{
distr[11] = unur_distr_multicauchy_ar1(2,NULL,0.2);
}

{
distr[12] = unur_distr_multicauchy_ar1(3,NULL,0.2);
}

{
distr[13] = unur_distr_multicauchy_ar1(4,NULL,0.2);
}

{
distr[14] = unur_distr_multicauchy_ar1(5,NULL,0.2);
}

{
distr[15] = unur_distr_multistudent_ar1(3,4,NULL,0.4);
}

{
distr[16] = unur_distr_multistudent_ar1(3,5,NULL,0.4);
}

{
distr[17] = unur_distr_multistudent_ar1(3,6,NULL,0.4);
}

{
distr[18] = unur_distr_multistudent_ar1(3,7,NULL,0.4);
}

{
distr[19] = unur_distr_multinormal_constantrho(2,NULL,0.5);
}

{
distr[20] = unur_distr_multinormal_constantrho(3,NULL,0.5);
}

{
distr[21] = unur_distr_multinormal_constantrho(4,NULL,0.5);
}

{
distr[22] = unur_distr_multinormal_constantrho(5,NULL,0.5);
}

{
distr[23] = unur_distr_multicauchy_constantrho(2,NULL,0.2);
}

{
distr[24] = unur_distr_multicauchy_constantrho(3,NULL,0.2);
}

{
distr[25] = unur_distr_multicauchy_constantrho(4,NULL,0.2);
}

{
distr[26] = unur_distr_multicauchy_constantrho(5,NULL,0.2);
}

{
distr[27] = unur_distr_multistudent_constantrho(3,4,NULL,0.4);
}

{
distr[28] = unur_distr_multistudent_constantrho(3,5,NULL,0.4);
}

{
distr[29] = unur_distr_multistudent_constantrho(3,6,NULL,0.4);
}

{
distr[30] = unur_distr_multistudent_constantrho(3,7,NULL,0.4);
}

	printf("\n(chi^2) "); fflush(stdout);

/* chi^2 tests: 155 */

	unur_set_default_debug(~UNUR_DEBUG_SAMPLE);
	fprintf( TESTLOG,"\nChi^2 Test:\n");

/* distribution [0] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[0]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[0],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[0]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_r(par,0.5);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[0],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[0]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[0],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[0]);
	unur_errno = 0;
{ double umin[] = {-0.608928,-0.608928,-0.608928};
double umax[] = { 0.608928, 0.608928, 0.608928};
double vmax = 0.51;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_u(par,umin,umax);
unur_vnrou_set_v(par,vmax); }
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[0],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

/* distribution [1] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[1]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[1],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[1]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_r(par,0.5);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[1],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[1]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[1],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[1]);
	unur_errno = 0;
{ double umin[] = {-0.608928,-0.608928,-0.608928};
double umax[] = { 0.608928, 0.608928, 0.608928};
double vmax = 0.51;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_u(par,umin,umax);
unur_vnrou_set_v(par,vmax); }
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[1],0,'-');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

/* distribution [2] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[2]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[2],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[2]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_r(par,0.5);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[2],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[2]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[2],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [3] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[3]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[3],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[3]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_r(par,0.5);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[3],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[3]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[3],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [4] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[4]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[4],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[4]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_r(par,0.5);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[4],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[4]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[4],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [5] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[5]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[5],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[5]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_r(par,0.5);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[5],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[5]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[5],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[5]);
	unur_errno = 0;
{ double umin[] = {-0.608928,-0.608928,-0.608928};
double umax[] = { 0.608928, 0.608928, 0.608928};
double vmax = 0.70;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_u(par,umin,umax);
unur_vnrou_set_v(par,vmax); }
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[5],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [6] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[6]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[6],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[6]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_r(par,0.5);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[6],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[6]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[6],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [7] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[7]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[7],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[7]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_r(par,0.5);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[7],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[7]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[7],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [8] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[8]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[8],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[8]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_r(par,0.5);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[8],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[8]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[8],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [9] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[9]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[9],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[9]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_r(par,0.5);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[9],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[9]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[9],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [10] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[10]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[10],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[10]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_r(par,0.5);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[10],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[10]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[10],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [11] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[11]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[11],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[11]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[11],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [12] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[12]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[12],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[12]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[12],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [13] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[13]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[13],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[13]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[13],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [14] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[14]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[14],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[14]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[14],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [15] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[15]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[15],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[15]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_r(par,0.5);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[15],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[15]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[15],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [16] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[16]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[16],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[16]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_r(par,0.5);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[16],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[16]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[16],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [17] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[17]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[17],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[17]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_r(par,0.5);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[17],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[17]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[17],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [18] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[18]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[18],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[18]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_r(par,0.5);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[18],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[18]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[18],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [19] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[19]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[19],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[19]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_r(par,0.5);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[19],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[19]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[19],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [20] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[20]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[20],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[20]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_r(par,0.5);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[20],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[20]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[20],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [21] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[21]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[21],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[21]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_r(par,0.5);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[21],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[21]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[21],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [22] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[22]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[22],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[22]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_r(par,0.5);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[22],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[22]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[22],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [23] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[23]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[23],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[23]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[23],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [24] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[24]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[24],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[24]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[24],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [25] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[25]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[25],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[25]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[25],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [26] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[26]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[26],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[26]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[26],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [27] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[27]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[27],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[27]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_r(par,0.5);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[27],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[27]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[27],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [28] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[28]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[28],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[28]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_r(par,0.5);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[28],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[28]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[28],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [29] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[29]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[29],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[29]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_r(par,0.5);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[29],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[29]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[29],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [30] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[30]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[30],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[30]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_r(par,0.5);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[30],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[30]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[30],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("\n(verify hat) "); fflush(stdout);

/* verify hat tests: 155 */

	unur_set_default_debug(~UNUR_DEBUG_SAMPLE);
	fprintf( TESTLOG,"\nVerify Hat Test (squeeze <= PDF <= hat):\n");

/* distribution [0] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[0]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[0],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[0]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_r(par,0.5);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[0],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[0]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[0],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[0]);
	unur_errno = 0;
{ double umin[] = {-0.608928,-0.608928,-0.608928};
double umax[] = { 0.608928, 0.608928, 0.608928};
double vmax = 0.51;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_u(par,umin,umax);
unur_vnrou_set_v(par,vmax); }
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[0],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

/* distribution [1] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[1]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[1],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[1]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_r(par,0.5);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[1],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[1]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[1],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[1]);
	unur_errno = 0;
{ double umin[] = {-0.608928,-0.608928,-0.608928};
double umax[] = { 0.608928, 0.608928, 0.608928};
double vmax = 0.51;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_u(par,umin,umax);
unur_vnrou_set_v(par,vmax); }
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[1],'-')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

/* distribution [2] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[2]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[2],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[2]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_r(par,0.5);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[2],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[2]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[2],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [3] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[3]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[3],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[3]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_r(par,0.5);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[3],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[3]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[3],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [4] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[4]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[4],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[4]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_r(par,0.5);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[4],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[4]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[4],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [5] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[5]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[5],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[5]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_r(par,0.5);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[5],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[5]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[5],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[5]);
	unur_errno = 0;
{ double umin[] = {-0.608928,-0.608928,-0.608928};
double umax[] = { 0.608928, 0.608928, 0.608928};
double vmax = 0.70;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_u(par,umin,umax);
unur_vnrou_set_v(par,vmax); }
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[5],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [6] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[6]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[6],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[6]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_r(par,0.5);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[6],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[6]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[6],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [7] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[7]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[7],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[7]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_r(par,0.5);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[7],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[7]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[7],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [8] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[8]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[8],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[8]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_r(par,0.5);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[8],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[8]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[8],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [9] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[9]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[9],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[9]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_r(par,0.5);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[9],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[9]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[9],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [10] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[10]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[10],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[10]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_r(par,0.5);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[10],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[10]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[10],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [11] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[11]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[11],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[11]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[11],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [12] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[12]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[12],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[12]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[12],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [13] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[13]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[13],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[13]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[13],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [14] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[14]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[14],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[14]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[14],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [15] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[15]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[15],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[15]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_r(par,0.5);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[15],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[15]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[15],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [16] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[16]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[16],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[16]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_r(par,0.5);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[16],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[16]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[16],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [17] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[17]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[17],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[17]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_r(par,0.5);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[17],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[17]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[17],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [18] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[18]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[18],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[18]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_r(par,0.5);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[18],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[18]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[18],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [19] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[19]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[19],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[19]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_r(par,0.5);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[19],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[19]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[19],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [20] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[20]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[20],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[20]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_r(par,0.5);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[20],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[20]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[20],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [21] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[21]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[21],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[21]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_r(par,0.5);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[21],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[21]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[21],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [22] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[22]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[22],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[22]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_r(par,0.5);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[22],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[22]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[22],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [23] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[23]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[23],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[23]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[23],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [24] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[24]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[24],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[24]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[24],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [25] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[25]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[25],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[25]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[25],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [26] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[26]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[26],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[26]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[26],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [27] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[27]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[27],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[27]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_r(par,0.5);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[27],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[27]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[27],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [28] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[28]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[28],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[28]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_r(par,0.5);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[28],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[28]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[28],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [29] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[29]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[29],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[29]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_r(par,0.5);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[29],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[29]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[29],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [30] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[30]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[30],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[30]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_r(par,0.5);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[30],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[30]);
	unur_errno = 0;
par = unur_vnrou_new(distr_localcopy);
	unur_vnrou_set_pedantic(par,0);
unur_vnrou_set_r(par,2);
	gen = unur_init(par);
	if (gen) unur_vnrou_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[30],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);


/* free distributions */
	unur_distr_free(distr[0]);
	unur_distr_free(distr[1]);
	unur_distr_free(distr[2]);
	unur_distr_free(distr[3]);
	unur_distr_free(distr[4]);
	unur_distr_free(distr[5]);
	unur_distr_free(distr[6]);
	unur_distr_free(distr[7]);
	unur_distr_free(distr[8]);
	unur_distr_free(distr[9]);
	unur_distr_free(distr[10]);
	unur_distr_free(distr[11]);
	unur_distr_free(distr[12]);
	unur_distr_free(distr[13]);
	unur_distr_free(distr[14]);
	unur_distr_free(distr[15]);
	unur_distr_free(distr[16]);
	unur_distr_free(distr[17]);
	unur_distr_free(distr[18]);
	unur_distr_free(distr[19]);
	unur_distr_free(distr[20]);
	unur_distr_free(distr[21]);
	unur_distr_free(distr[22]);
	unur_distr_free(distr[23]);
	unur_distr_free(distr[24]);
	unur_distr_free(distr[25]);
	unur_distr_free(distr[26]);
	unur_distr_free(distr[27]);
	unur_distr_free(distr[28]);
	unur_distr_free(distr[29]);
	unur_distr_free(distr[30]);
#if WITH_DMALLOC
	dmalloc_vmessage("section = validate  ================================\n","");
	dmalloc_log_unfreed();
#endif


	/* test finished */
	test_ok &= (n_tests_failed>CHI2_FAILURES_TOLERATED) ? 0 : 1;
	/* we accept CHI2_FAILURES_TOLERATED failures */
	(n_tests_failed>CHI2_FAILURES_TOLERATED) ? printf(" ==> failed] ") : printf(" ==> ok] ");

	/* prevent compiler from making useless annoying warnings */
	distr[0] = NULL;
	par = NULL;
	gen = NULL;
	darray = NULL;
	fpm[0] = 0.;

} /* end of test_validate */


/*---------------------------------------------------------------------------*/
/* run generator in verifying mode */

void run_verify_generator( FILE *LOG, int line, UNUR_PAR *par )
{
	UNUR_GEN *gen;
	int i;

	/* switch to verifying mode */
	unur_vnrou_set_verify(par,1);

	/* initialize generator */
	gen = unur_init( par ); abort_if_NULL(LOG, line, gen);

	/* run generator */
	for (i=0; i<VIOLATE_SAMPLE_SIZE; i++)
		unur_sample_cont(gen);

	/* destroy generator */
	unur_free(gen); 

} /* end of run_verify_generator() */


/*---------------------------------------------------------------------------*/

int main()
{ 
	/* open log file for unuran and set output stream for unuran messages */
	UNURANLOG = fopen( "t_vnrou_unuran.log","w" );
	abort_if_NULL( stderr,-1, UNURANLOG );
	unur_set_stream( UNURANLOG );

	/* open log file for testing */
	TESTLOG = fopen( "t_vnrou_test.log","w" );
	abort_if_NULL( stderr,-1, TESTLOG );

	/* write header into log file */
  	{
		time_t started;  
		fprintf(TESTLOG,"\nUNURAN - Universal Non-Uniform RANdom number generator\n\n");
		if (time( &started ) != -1)
			fprintf(TESTLOG,"%s",ctime(&started));
		fprintf(TESTLOG,"\n====================================================\n\n");
	}

        /* seed build-in uniform generators */
        unur_urng_MRG31k3p_seed(772529);
	unur_urng_fish_seed(772529);
	unur_urng_mstd_seed(772529);

	/* seed uniform random number generator */
#if UNUR_URNG_TYPE == UNUR_URNG_GENERIC
/*
	if (unur_urng_seed(NULL, 772529) != UNUR_SUCCESS) {
	  fprintf(stderr,"WARNING: Seed could not be set at random\n");
	}  
*/
#elif UNUR_URNG_TYPE == UNUR_URNG_PRNG
	unur_set_default_urng(prng_new("mt19937(772529)"));
#elif UNUR_URNG_TYPE == UNUR_URNG_RNGSTREAM
	{
	    unsigned long seed[6] = {772529,772529,772529,772529,772529,772529};
	    RngStream_SetPackageSeed(seed);
	}
#endif  /* UNUR_URNG_TYPE */

	/* set default debugging flag */
	unur_set_default_debug(UNUR_DEBUG_ALL);

	/* start test */
	printf("vnrou: ");

	/* run tests */
test_new();
test_set();
test_get();
test_chg();
test_init();
test_reinit();
test_sample();
test_validate();


	/* test finished */
	printf("\n");  fflush(stdout);

	/* close log files */
	fprintf(TESTLOG,"\n====================================================\n\n");
	if (test_ok)
		fprintf(TESTLOG,"All tests PASSED.\n");
	else
		fprintf(TESTLOG,"Test(s) FAILED.\n");

	fclose(UNURANLOG);
	fclose(TESTLOG);

	/* free memory */
        compare_free_memory();

	/* exit */
	exit( (test_ok) ? EXIT_SUCCESS : EXIT_FAILURE );

} /* end of main */

