/*
	file automatically generated by make_test_files.pl
	Thu Jan  5 10:45:17 2006
*/

/*****************************************************************************
 *                                                                           *
 *          UNURAN -- Universal Non-Uniform Random number generator          *
 *                                                                           *
 *****************************************************************************/
    
/**
 ** Tests for TDRGW
 **/
    
/*---------------------------------------------------------------------------*/
#include "testunuran.h"
/*---------------------------------------------------------------------------*/

/*---------------------------------------------------------------------------*/
/* global variables                                                          */

static FILE *TESTLOG;               /* test log file                         */
static FILE *UNURANLOG;             /* unuran log file                       */

static int test_ok = TRUE;          /* all tests ok (boolean)                */
static int n_tests_failed;          /* number of failed tests                */

/*---------------------------------------------------------------------------*/

void run_verify_generator( FILE *LOG, int line, UNUR_PAR *par );

int unur_tdrgw_set_verify( UNUR_PAR *par, int );

/*---------------------------------------------------------------------------*/



/* prototypes */
double logpdf_normal_1( double x, const UNUR_DISTR *distr );
double dlogpdf_normal_1( double x, const UNUR_DISTR *distr );
double cdf_normal_1( double x, const UNUR_DISTR *distr );
double logpdf_normal_2( double x, const UNUR_DISTR *distr );
double dlogpdf_normal_2( double x, const UNUR_DISTR *distr );
double cdf_normal_2( double x, const UNUR_DISTR *distr );

#define COMPARE_SAMPLE_SIZE   (10000)
#define VIOLATE_SAMPLE_SIZE   (20)




/*---------------------------------------------------------------------------*/

#ifndef CHI2_FAILURES_TOLERATED
#  define CHI2_FAILURES_TOLERATED DEFAULT_CHI2_FAILURES_TOLERATED
#endif

/*---------------------------------------------------------------------------*/
/* [verbatim] */



/* logPDF of normal density */
double logpdf_normal_1( double x, const UNUR_DISTR *distr )  { return (-x*x/2. - 10000.); }
double dlogpdf_normal_1( double x, const UNUR_DISTR *distr ) { return (-x); }

double cdf_normal_1( double x, const UNUR_DISTR *distr ) 
{ 
	static UNUR_DISTR *normal = NULL;
	static double fpm[2] = {0., 1.};
	if (normal == NULL) normal = unur_distr_normal(fpm,2);
	return unur_distr_cont_eval_cdf( x, normal );
}

/* ......................................................................... */

#define mu_2 (100.)

double logpdf_normal_2( double x, const UNUR_DISTR *distr )  { return (-(x-mu_2)*(x-mu_2)/2. - 10000.); }
double dlogpdf_normal_2( double x, const UNUR_DISTR *distr ) { return (-(x-mu_2)); }

double cdf_normal_2( double x, const UNUR_DISTR *distr ) 
{ 
	static UNUR_DISTR *normal_2 = NULL;
	static double fpm[2] = {mu_2, 1.};
	if (normal_2 == NULL) normal_2 = unur_distr_normal(fpm,2);
	return unur_distr_cont_eval_cdf( x, normal_2 );
}


/*---------------------------------------------------------------------------*/
/* [new] */

void test_new (void)
{
	/* start test */
	printf("[new "); fflush(stdout);
	fprintf(TESTLOG,"\n[new]\n");

	/* reset counter */
	n_tests_failed = 0;
  
{ /* invalid NULL ptr */
UNUR_DISTR *distr = NULL;
   distr = NULL; 


unur_errno = 0;
n_tests_failed += (check_expected_NULL(TESTLOG,32,(unur_tdrgw_new( distr )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,32,UNUR_ERR_NULL)==UNUR_SUCCESS)?0:1;
unur_distr_free(distr);
}

{ /* invalid distribution type */
UNUR_DISTR *distr = NULL;
   distr = unur_distr_discr_new(); 


unur_errno = 0;
n_tests_failed += (check_expected_NULL(TESTLOG,38,(unur_tdrgw_new( distr )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,38,UNUR_ERR_DISTR_INVALID)==UNUR_SUCCESS)?0:1;
unur_distr_free(distr);
}

{ /* data missing in distribution object */
UNUR_DISTR *distr = NULL;
   distr = unur_distr_normal_wo_logpdf(NULL,0); 


unur_errno = 0;
n_tests_failed += (check_expected_NULL(TESTLOG,44,(unur_tdrgw_new( distr )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,44,UNUR_ERR_DISTR_REQUIRED)==UNUR_SUCCESS)?0:1;
unur_distr_free(distr);
}

{ /* data missing in distribution object */
UNUR_DISTR *distr = NULL;
   distr = unur_distr_cont_new(); 


unur_errno = 0;
/* logpdf, dlogpdf */
n_tests_failed += (check_expected_NULL(TESTLOG,52,(unur_tdrgw_new( distr )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,52,UNUR_ERR_DISTR_REQUIRED)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
/* dlogpdf */
unur_distr_cont_set_logpdf(distr,logpdf_normal_1);
n_tests_failed += (check_expected_NULL(TESTLOG,57,(unur_tdrgw_new( distr )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,57,UNUR_ERR_DISTR_REQUIRED)==UNUR_SUCCESS)?0:1;
unur_distr_free(distr);
}


	/* test finished */
	test_ok &= (n_tests_failed) ? 0 : 1;
	(n_tests_failed) ? printf(" ==> failed] ") : printf(" ==> ok] ");

#if WITH_DMALLOC
	dmalloc_vmessage("section = new  ================================\n",NULL);
	dmalloc_log_unfreed();
#endif

} /* end of test_new() */

/*---------------------------------------------------------------------------*/
/* [set] */

void test_set (void)
{
	/* start test */
	printf("[set "); fflush(stdout);
	fprintf(TESTLOG,"\n[set]\n");

	/* reset counter */
	n_tests_failed = 0;
  
{ /* invalid NULL ptr */
UNUR_PAR   *par = NULL;
   par = NULL; 


unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,67,(unur_tdrgw_set_cpoints( par, 0, NULL )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,67,UNUR_ERR_NULL)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,70,(unur_tdrgw_set_reinit_percentiles( par, 0, NULL )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,70,UNUR_ERR_NULL)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,73,(unur_tdrgw_set_reinit_ncpoints( par, 20 )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,73,UNUR_ERR_NULL)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,76,(unur_tdrgw_set_max_intervals( par, 100 )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,76,UNUR_ERR_NULL)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,79,(unur_tdrgw_set_verify( par, 1 )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,79,UNUR_ERR_NULL)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,82,(unur_tdrgw_set_pedantic( par, 1 )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,82,UNUR_ERR_NULL)==UNUR_SUCCESS)?0:1;
}

{ /* invalid parameter object */
UNUR_DISTR *distr = NULL;
UNUR_PAR   *par = NULL;
   distr = unur_distr_normal(NULL,0);
   par = unur_tdr_new(distr); 


unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,90,(unur_tdrgw_set_cpoints( par, 0, NULL )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,90,UNUR_ERR_PAR_INVALID)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,93,(unur_tdrgw_set_reinit_percentiles( par, 0, NULL )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,93,UNUR_ERR_PAR_INVALID)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,96,(unur_tdrgw_set_reinit_ncpoints( par, 30 )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,96,UNUR_ERR_PAR_INVALID)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,99,(unur_tdrgw_set_max_intervals( par, 100 )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,99,UNUR_ERR_PAR_INVALID)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,102,(unur_tdrgw_set_verify( par, 1 )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,102,UNUR_ERR_PAR_INVALID)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,105,(unur_tdrgw_set_pedantic( par, 1 )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,105,UNUR_ERR_PAR_INVALID)==UNUR_SUCCESS)?0:1;
unur_par_free(par);
unur_distr_free(distr);
}

{ /* invalid parameters */
UNUR_DISTR *distr = NULL;
UNUR_PAR   *par = NULL;
   double stp[] = {1.,0.,1.};
   double perc[] = {0.1,0.4,0.2};
   int n_stp = 3;
   double fpar[2] = {0.,1.};
   distr = unur_distr_normal(fpar,2);
   par = unur_tdrgw_new(distr); 


unur_errno = 0;
unur_tdrgw_set_cpoints( par, -1, NULL );
n_tests_failed += (check_errorcode(TESTLOG,118,UNUR_ERR_PAR_SET)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,121,(unur_tdrgw_set_cpoints( par, n_stp, stp )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,121,UNUR_ERR_PAR_SET)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
unur_tdrgw_set_reinit_percentiles( par, -1, NULL );
n_tests_failed += (check_errorcode(TESTLOG,124,UNUR_ERR_PAR_SET)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,127,(unur_tdrgw_set_reinit_percentiles( par, n_stp, stp )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,127,UNUR_ERR_PAR_SET)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,130,(unur_tdrgw_set_reinit_percentiles( par, n_stp, perc )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,130,UNUR_ERR_PAR_SET)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,133,(unur_tdrgw_set_reinit_ncpoints( par, 9 )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,133,UNUR_ERR_PAR_SET)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,136,(unur_tdrgw_set_max_intervals( par, 0 )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,136,UNUR_ERR_PAR_SET)==UNUR_SUCCESS)?0:1;
unur_par_free(par);
unur_distr_free(distr);
}


	/* test finished */
	test_ok &= (n_tests_failed) ? 0 : 1;
	(n_tests_failed) ? printf(" ==> failed] ") : printf(" ==> ok] ");

#if WITH_DMALLOC
	dmalloc_vmessage("section = set  ================================\n",NULL);
	dmalloc_log_unfreed();
#endif

} /* end of test_set() */

/*---------------------------------------------------------------------------*/
/* [get] */

void test_get (void)
{
	/* start test */
	printf("[get "); fflush(stdout);
	fprintf(TESTLOG,"\n[get]\n");

	/* reset counter */
	n_tests_failed = 0;
  
{ /* invalid generator object */
UNUR_DISTR *distr = NULL;
UNUR_PAR   *par = NULL;
UNUR_GEN   *gen = NULL;
   distr = unur_distr_normal(NULL,0);
   par = unur_tdr_new(distr);
   gen = unur_init(par); 
abort_if_NULL(TESTLOG, 146,    gen );


unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,150,(unur_tdrgw_get_loghatarea(gen)))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,150,UNUR_ERR_GEN_INVALID)==UNUR_SUCCESS)?0:1;
unur_distr_free(distr);
unur_free(gen);
}


	/* test finished */
	test_ok &= (n_tests_failed) ? 0 : 1;
	(n_tests_failed) ? printf(" ==> failed] ") : printf(" ==> ok] ");

#if WITH_DMALLOC
	dmalloc_vmessage("section = get  ================================\n",NULL);
	dmalloc_log_unfreed();
#endif

} /* end of test_get() */

/*---------------------------------------------------------------------------*/
/* [chg] */

void test_chg (void)
{
	/* start test */
	printf("[chg "); fflush(stdout);
	fprintf(TESTLOG,"\n[chg]\n");

	/* reset counter */
	n_tests_failed = 0;
  
{ /* invalid generator object */
UNUR_DISTR *distr = NULL;
UNUR_PAR   *par = NULL;
UNUR_GEN   *gen = NULL;
   double fpar[2] = {0.,1.};
   distr = unur_distr_normal(fpar,2);
   par = unur_tdr_new(distr);
   unur_set_debug(par,0);
   gen = unur_init( par ); 
abort_if_NULL(TESTLOG, 160,    gen );


unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,164,(unur_tdrgw_chg_verify(gen,1)))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,164,UNUR_ERR_GEN_INVALID)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,167,(unur_tdrgw_chg_reinit_percentiles(gen, -1, NULL)))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,167,UNUR_ERR_GEN_INVALID)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,170,(unur_tdrgw_chg_reinit_ncpoints(gen, 30)))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,170,UNUR_ERR_GEN_INVALID)==UNUR_SUCCESS)?0:1;
unur_distr_free(distr);
unur_free(gen);
}

{ /* invalid parameters */
UNUR_DISTR *distr = NULL;
UNUR_PAR   *par = NULL;
UNUR_GEN   *gen = NULL;
   double percmon[] = {0.1,0.4,0.2};
   double percdom[] = {0.1,0.4,2.};
   int n_perc = 3;
   distr = unur_distr_normal(NULL,0);
   par = unur_tdrgw_new(distr); 
   unur_set_debug(par,0);
   gen = unur_init( par ); 
abort_if_NULL(TESTLOG, 179,    gen );


unur_errno = 0;
unur_tdrgw_chg_reinit_percentiles( gen, -1, NULL );
n_tests_failed += (check_errorcode(TESTLOG,183,UNUR_ERR_PAR_SET)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,186,(unur_tdrgw_chg_reinit_percentiles( gen, n_perc, percmon )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,186,UNUR_ERR_PAR_SET)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,189,(unur_tdrgw_chg_reinit_percentiles( gen, n_perc, percdom )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,189,UNUR_ERR_PAR_SET)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_setfailed(TESTLOG,192,(unur_tdrgw_chg_reinit_ncpoints( gen, 0 )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,192,UNUR_ERR_PAR_SET)==UNUR_SUCCESS)?0:1;
unur_distr_free(distr);
unur_free(gen);
}


	/* test finished */
	test_ok &= (n_tests_failed) ? 0 : 1;
	(n_tests_failed) ? printf(" ==> failed] ") : printf(" ==> ok] ");

#if WITH_DMALLOC
	dmalloc_vmessage("section = chg  ================================\n",NULL);
	dmalloc_log_unfreed();
#endif

} /* end of test_chg() */

/*---------------------------------------------------------------------------*/
/* [init] */

void test_init (void)
{
	/* start test */
	printf("[init "); fflush(stdout);
	fprintf(TESTLOG,"\n[init]\n");

	/* reset counter */
	n_tests_failed = 0;
  
{ /* invalid NULL ptr */
UNUR_PAR   *par = NULL;
   par = NULL; 


unur_errno = 0;
n_tests_failed += (check_expected_NULL(TESTLOG,203,(unur_init( par )))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,203,UNUR_ERR_NULL)==UNUR_SUCCESS)?0:1;
}

{ /* stp out of domain */
UNUR_GEN   *gen = NULL;
UNUR_DISTR *distr = NULL;
UNUR_PAR   *par = NULL;
   double stp[] = {-2.5,-1.,0.,1.,2.5};
   int n_stp = 5;
   gen = NULL;
   distr = unur_distr_normal(NULL,0);
   unur_distr_cont_set_domain(distr,-2.,2.);
   par = unur_tdrgw_new(distr);
   unur_tdrgw_set_cpoints( par, n_stp, stp ); 


unur_errno = 0;
gen = unur_init( par );
n_tests_failed += (check_errorcode(TESTLOG,215,UNUR_ERR_GEN_DATA)==UNUR_SUCCESS)?0:1;
unur_free(gen);
unur_distr_free(distr);
}


	/* test finished */
	test_ok &= (n_tests_failed) ? 0 : 1;
	(n_tests_failed) ? printf(" ==> failed] ") : printf(" ==> ok] ");

#if WITH_DMALLOC
	dmalloc_vmessage("section = init  ================================\n",NULL);
	dmalloc_log_unfreed();
#endif

} /* end of test_init() */

/*---------------------------------------------------------------------------*/
/* [reinit] */

void test_reinit (void)
{
	/* start test */
	printf("[reinit "); fflush(stdout);
	fprintf(TESTLOG,"\n[reinit]\n");

	/* reset counter */
	n_tests_failed = 0;
  
{ /* exist */
UNUR_DISTR *distr = NULL;
UNUR_PAR   *par = NULL;
UNUR_GEN   *gen = NULL;
   distr = unur_distr_normal(NULL,0);
   par = unur_tdrgw_new(distr);
   unur_set_use_distr_privatecopy(par,FALSE);
   gen = unur_init( par ); 
abort_if_NULL(TESTLOG, 225,    gen );


unur_errno = 0;
n_tests_failed += (check_expected_reinit(TESTLOG,229,(unur_tdrgw_reinit( gen )))==UNUR_SUCCESS)?0:1;
unur_distr_free(distr);
unur_free(gen);
}


	/* test finished */
	test_ok &= (n_tests_failed) ? 0 : 1;
	(n_tests_failed) ? printf(" ==> failed] ") : printf(" ==> ok] ");

#if WITH_DMALLOC
	dmalloc_vmessage("section = reinit  ================================\n",NULL);
	dmalloc_log_unfreed();
#endif

} /* end of test_reinit() */

/*---------------------------------------------------------------------------*/
/* [sample] */

void test_sample (void)
{
	/* start test */
	printf("[sample "); fflush(stdout);
	fprintf(TESTLOG,"\n[sample]\n");

	/* reset counter */
	n_tests_failed = 0;
  
{ /* invalid NULL ptr */
UNUR_GEN   *gen = NULL;
   gen = NULL; 


unur_errno = 0;
n_tests_failed += (check_expected_INFINITY(TESTLOG,239,(unur_tdrgw_eval_invcdfhat(gen,0.5)))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,239,UNUR_ERR_NULL)==UNUR_SUCCESS)?0:1;
unur_free(gen);
}

{ /* invalid generator object */
UNUR_DISTR *distr = NULL;
UNUR_PAR   *par = NULL;
UNUR_GEN   *gen = NULL;
   distr = unur_distr_normal(NULL,0);
   par = unur_arou_new(distr);
   gen = unur_init(par); 
abort_if_NULL(TESTLOG, 245,    gen );


unur_errno = 0;
n_tests_failed += (check_expected_INFINITY(TESTLOG,249,(unur_tdrgw_eval_invcdfhat(gen,0.5)))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,249,UNUR_ERR_GEN_INVALID)==UNUR_SUCCESS)?0:1;
unur_distr_free(distr);
unur_free(gen);
}

{ /* invalid domain */
UNUR_DISTR *distr = NULL;
UNUR_PAR   *par = NULL;
UNUR_GEN   *gen = NULL;
   distr = unur_distr_normal(NULL,0);
   par = unur_tdrgw_new(distr);
   gen = unur_init( par ); 
abort_if_NULL(TESTLOG, 255,    gen );


unur_errno = 0;
n_tests_failed += (check_expected_INFINITY(TESTLOG,259,(unur_tdrgw_eval_invcdfhat(gen,1.5)))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,259,UNUR_ERR_DOMAIN)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
n_tests_failed += (check_expected_negINFINITY(TESTLOG,262,(unur_tdrgw_eval_invcdfhat(gen,-0.5)))==UNUR_SUCCESS)?0:1;
n_tests_failed += (check_errorcode(TESTLOG,262,UNUR_ERR_DOMAIN)==UNUR_SUCCESS)?0:1;
unur_distr_free(distr);
unur_free(gen);
}

{ /* compare */
UNUR_DISTR *distr = NULL;
UNUR_PAR   *par = NULL;
   distr = unur_distr_normal(NULL,0); 
   par = NULL; 


unur_errno = 0;
/* default */
par = unur_tdrgw_new(distr);
n_tests_failed += (compare_double_sequence_par_start(TESTLOG,272,par,COMPARE_SAMPLE_SIZE)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
/* verifying mode */
par = unur_tdrgw_new(distr);
unur_tdrgw_set_verify(par,1);
n_tests_failed += (compare_double_sequence_par(TESTLOG,277,par,COMPARE_SAMPLE_SIZE)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
/* don't use private copy for distr object */
par = unur_tdrgw_new(distr);
unur_set_use_distr_privatecopy(par,FALSE);
n_tests_failed += (compare_double_sequence_par(TESTLOG,282,par,COMPARE_SAMPLE_SIZE)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
/* verifying mode, don't use private copy for distr object */
par = unur_tdrgw_new(distr);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_verify(par,1);
n_tests_failed += (compare_double_sequence_par(TESTLOG,288,par,COMPARE_SAMPLE_SIZE)==UNUR_SUCCESS)?0:1;
unur_distr_free(distr);
}

{ /* compare clone */
UNUR_DISTR *distr = NULL;
UNUR_PAR   *par = NULL;
UNUR_GEN   *gen = NULL;
   UNUR_GEN *clone;
   double fpar[] = {1.23456,2.3456}; 
   distr = unur_distr_normal(fpar,2);
   par = NULL;
   gen = NULL; 


unur_errno = 0;
/* original generator object */
par = unur_tdrgw_new(distr);
unur_tdrgw_set_max_intervals(par,2);
gen = unur_init(par);
n_tests_failed += (compare_double_sequence_gen_start(TESTLOG,303,gen,COMPARE_SAMPLE_SIZE)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
/* clone */
clone = unur_gen_clone(gen);
unur_free(gen);
gen = clone;
n_tests_failed += (compare_double_sequence_gen(TESTLOG,309,gen,COMPARE_SAMPLE_SIZE)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
/* dont use private copy for distr object */
/* original generator object */
unur_free(clone);
par = unur_tdrgw_new(distr);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_max_intervals(par,2);
gen = unur_init(par);
n_tests_failed += (compare_double_sequence_gen_start(TESTLOG,318,gen,COMPARE_SAMPLE_SIZE)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
/* clone */
clone = unur_gen_clone(gen);
unur_free(gen);
gen = clone;
n_tests_failed += (compare_double_sequence_gen(TESTLOG,324,gen,COMPARE_SAMPLE_SIZE)==UNUR_SUCCESS)?0:1;
unur_distr_free(distr);
unur_free(gen);
}

{ /* compare stringparser */
UNUR_DISTR *distr = NULL;
UNUR_PAR   *par = NULL;
UNUR_GEN   *gen = NULL;
   double fpar[2] = {3.,3.};
   distr = NULL;
   par = NULL;
   gen = NULL; 


unur_errno = 0;
distr = unur_distr_gamma(fpar,2);
par = unur_tdrgw_new(distr);
gen = unur_init(par);
n_tests_failed += (compare_double_sequence_gen_start(TESTLOG,337,gen,COMPARE_SAMPLE_SIZE)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
unur_free(gen); gen = NULL;
unur_distr_free(distr); distr = NULL;
gen = unur_str2gen( "gamma(3.,3.) & method = tdrgw ");
n_tests_failed += (compare_double_sequence_gen(TESTLOG,342,gen,COMPARE_SAMPLE_SIZE)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
unur_free(gen); gen = NULL;
distr = unur_distr_gamma(fpar,2);
par = unur_tdrgw_new(distr);
unur_tdrgw_set_cpoints(par,20,NULL);
unur_tdrgw_set_max_intervals(par,32);
unur_tdrgw_set_verify(par,TRUE);
gen = unur_init(par);
n_tests_failed += (compare_double_sequence_gen_start(TESTLOG,352,gen,COMPARE_SAMPLE_SIZE)==UNUR_SUCCESS)?0:1;

unur_errno = 0;
unur_free(gen); gen = NULL;
unur_distr_free(distr); distr = NULL;
gen = unur_str2gen( "gamma(3.,3.) & \
  method = tdrgw; cpoints = 20; \
  max_intervals = 32; verify" );
n_tests_failed += (compare_double_sequence_gen(TESTLOG,359,gen,COMPARE_SAMPLE_SIZE)==UNUR_SUCCESS)?0:1;
unur_distr_free(distr);
unur_free(gen);
}


	/* test finished */
	test_ok &= (n_tests_failed) ? 0 : 1;
	(n_tests_failed) ? printf(" ==> failed] ") : printf(" ==> ok] ");

#if WITH_DMALLOC
	dmalloc_vmessage("section = sample  ================================\n",NULL);
	dmalloc_log_unfreed();
#endif

} /* end of test_sample() */

/*---------------------------------------------------------------------------*/
/* [validate] */

/*---------------------------------------------------------------------------*/

/* [validate] */

void test_validate (void)
{
	UNUR_DISTR *distr[31];
	UNUR_PAR *par;
	UNUR_GEN *gen;
	int n_tests_failed = 0;
	int rcode;
	double *darray;
	double fpm[10];

	rcode = 0;

	/* start test */
	printf("[validate "); fflush(stdout);
	fprintf(TESTLOG,"\n[validate]\n");

	/* reset counter */
	n_tests_failed = 0;


/* distributions: 31 */
{
fpm[0] = 1.;
fpm[1] = 2.;
distr[0] = unur_distr_beta(fpm,2);
}

{
fpm[0] = 1.;
fpm[1] = 5.;
distr[1] = unur_distr_beta(fpm,2);
}

{
fpm[0] = 1.;
fpm[1] = 100.;
distr[2] = unur_distr_beta(fpm,2);
}

{
fpm[0] = 2.;
fpm[1] = 5.;
distr[3] = unur_distr_beta(fpm,2);
}

{
fpm[0] = 5.;
fpm[1] = 2.;
distr[4] = unur_distr_beta(fpm,2);
}

{
fpm[0] = 3.;
fpm[1] = 4.;
distr[5] = unur_distr_beta(fpm,2);
}

{
fpm[0] = 5.;
fpm[1] = 100.;
distr[6] = unur_distr_beta(fpm,2);
}

{
fpm[0] = 500.;
fpm[1] = 300.;
distr[7] = unur_distr_beta(fpm,2);
}

{
fpm[0] = 5.;
fpm[1] = 10.;
fpm[2] = -3.;
fpm[3] = 15.;
distr[8] = unur_distr_beta(fpm,4);
}

{
distr[9] = unur_distr_cauchy(NULL,0);
}

{
fpm[0] = 1.;
fpm[1] = 20.;
distr[10] = unur_distr_cauchy(fpm,2);
}

{
distr[11] = unur_distr_exponential(NULL,0);
}

{
fpm[0] = 30.;
fpm[1] = -5.;
distr[12] = unur_distr_exponential(fpm,2);
}

{
fpm[0] = 1.;
distr[13] = unur_distr_gamma(fpm,1);
}

{
fpm[0] = 2.;
distr[14] = unur_distr_gamma(fpm,1);
}

{
fpm[0] = 3.;
distr[15] = unur_distr_gamma(fpm,1);
}

{
fpm[0] = 10.;
distr[16] = unur_distr_gamma(fpm,1);
}

{
fpm[0] = 1000.;
distr[17] = unur_distr_gamma(fpm,1);
}

{
fpm[0] = 5.;
fpm[1] = 1000.;
distr[18] = unur_distr_gamma(fpm,2);
}

{
fpm[0] = 5.;
fpm[1] = 1.e-5;
distr[19] = unur_distr_gamma(fpm,2);
}

{
fpm[0] = 5.;
fpm[1] = 10.;
fpm[2] = 1000;
distr[20] = unur_distr_gamma(fpm,3);
}

{
distr[21] = unur_distr_laplace(NULL,0);
}

{
fpm[0] = -10.;
fpm[1] = 100.;
distr[22] = unur_distr_laplace(fpm,2);
}

{
distr[23] = unur_distr_normal(NULL,0);
}

{
fpm[0] = 1.;
fpm[1] = 1.e-5;
distr[24] = unur_distr_normal(fpm,2);
}

{
fpm[0] = 0.;
fpm[1] = 1.e+5;
distr[25] = unur_distr_normal(fpm,2);
}

{
distr[26] = unur_distr_uniform(NULL,0);
}

{
fpm[0] = 1.;
fpm[1] = 20.;
distr[27] = unur_distr_uniform(fpm,2);
}

{
fpm[0] = 3.;
fpm[1] = 4.;
distr[28] = unur_distr_beta(fpm,2);
unur_distr_cont_set_domain(distr[23],-2.,5.);
}

{
distr[29] = unur_distr_cont_new();
unur_distr_cont_set_logpdf(distr[29],logpdf_normal_1);
unur_distr_cont_set_dlogpdf(distr[29],dlogpdf_normal_1);
unur_distr_cont_set_cdf(distr[29],cdf_normal_1);
unur_distr_set_name(distr[29],"normal_1"); 
}

{
distr[30] = unur_distr_cont_new();
unur_distr_cont_set_logpdf(distr[30],logpdf_normal_2);
unur_distr_cont_set_dlogpdf(distr[30],dlogpdf_normal_2);
unur_distr_cont_set_cdf(distr[30],cdf_normal_2);
unur_distr_set_name(distr[30],"normal_2"); 
}

	printf("\n(chi^2) "); fflush(stdout);

/* chi^2 tests: 217 */

	unur_set_default_debug(~UNUR_DEBUG_SAMPLE);
	fprintf( TESTLOG,"\nChi^2 Test:\n");

/* distribution [0] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[0]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[0],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[0]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[0],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[0]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_tdrgw_set_cpoints(par,3,NULL);
unur_tdrgw_set_max_intervals(par,10);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[0],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[0]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[0],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[0]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[0],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[0]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 2, NULL );
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[0],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[0]);
	unur_errno = 0;
double perc[] = {0.1,0.3,0.5,0.7,0.9};
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 5, perc );
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[0],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [1] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[1]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[1],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[1]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[1],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[1]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_tdrgw_set_cpoints(par,3,NULL);
unur_tdrgw_set_max_intervals(par,10);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[1],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[1]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[1],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[1]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[1],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[1]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 2, NULL );
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[1],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[1]);
	unur_errno = 0;
double perc[] = {0.1,0.3,0.5,0.7,0.9};
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 5, perc );
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[1],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [2] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[2]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[2],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[2]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[2],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[2]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_tdrgw_set_cpoints(par,3,NULL);
unur_tdrgw_set_max_intervals(par,10);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[2],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[2]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[2],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[2]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[2],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[2]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 2, NULL );
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[2],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[2]);
	unur_errno = 0;
double perc[] = {0.1,0.3,0.5,0.7,0.9};
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 5, perc );
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[2],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [3] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[3]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[3],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[3]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[3],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[3]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_tdrgw_set_cpoints(par,3,NULL);
unur_tdrgw_set_max_intervals(par,10);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[3],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[3]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[3],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[3]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[3],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[3]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 2, NULL );
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[3],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[3]);
	unur_errno = 0;
double perc[] = {0.1,0.3,0.5,0.7,0.9};
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 5, perc );
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[3],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [4] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[4]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[4],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[4]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[4],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[4]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_tdrgw_set_cpoints(par,3,NULL);
unur_tdrgw_set_max_intervals(par,10);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[4],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[4]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[4],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[4]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[4],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[4]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 2, NULL );
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[4],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[4]);
	unur_errno = 0;
double perc[] = {0.1,0.3,0.5,0.7,0.9};
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 5, perc );
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[4],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [5] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[5]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[5],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[5]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[5],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[5]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_tdrgw_set_cpoints(par,3,NULL);
unur_tdrgw_set_max_intervals(par,10);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[5],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[5]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[5],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[5]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[5],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[5]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 2, NULL );
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[5],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[5]);
	unur_errno = 0;
double perc[] = {0.1,0.3,0.5,0.7,0.9};
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 5, perc );
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[5],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [6] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[6]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[6],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[6]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[6],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[6]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_tdrgw_set_cpoints(par,3,NULL);
unur_tdrgw_set_max_intervals(par,10);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[6],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[6]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[6],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[6]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[6],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[6]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 2, NULL );
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[6],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[6]);
	unur_errno = 0;
double perc[] = {0.1,0.3,0.5,0.7,0.9};
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 5, perc );
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[6],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [7] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[7]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[7],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[7]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[7],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[7]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_tdrgw_set_cpoints(par,3,NULL);
unur_tdrgw_set_max_intervals(par,10);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[7],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[7]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[7],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[7]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[7],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[7]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 2, NULL );
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[7],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[7]);
	unur_errno = 0;
double perc[] = {0.1,0.3,0.5,0.7,0.9};
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 5, perc );
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[7],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [8] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[8]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[8],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[8]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[8],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[8]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_tdrgw_set_cpoints(par,3,NULL);
unur_tdrgw_set_max_intervals(par,10);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[8],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[8]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[8],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[8]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[8],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[8]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 2, NULL );
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[8],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[8]);
	unur_errno = 0;
double perc[] = {0.1,0.3,0.5,0.7,0.9};
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 5, perc );
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[8],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [9] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[9]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[9],0,'-');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[9]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[9],0,'-');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[9]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_tdrgw_set_cpoints(par,3,NULL);
unur_tdrgw_set_max_intervals(par,10);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[9],0,'-');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[9]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[9],0,'-');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [10] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[10]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[10],0,'-');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[10]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[10],0,'-');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[10]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_tdrgw_set_cpoints(par,3,NULL);
unur_tdrgw_set_max_intervals(par,10);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[10],0,'-');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[10]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[10],0,'-');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [11] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[11]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[11],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[11]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[11],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[11]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_tdrgw_set_cpoints(par,3,NULL);
unur_tdrgw_set_max_intervals(par,10);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[11],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[11]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[11],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[11]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[11],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[11]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 2, NULL );
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[11],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[11]);
	unur_errno = 0;
double perc[] = {0.1,0.3,0.5,0.7,0.9};
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 5, perc );
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[11],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [12] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[12]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[12],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[12]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[12],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[12]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_tdrgw_set_cpoints(par,3,NULL);
unur_tdrgw_set_max_intervals(par,10);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[12],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[12]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[12],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[12]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[12],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[12]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 2, NULL );
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[12],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[12]);
	unur_errno = 0;
double perc[] = {0.1,0.3,0.5,0.7,0.9};
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 5, perc );
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[12],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [13] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[13]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[13],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[13]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[13],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[13]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_tdrgw_set_cpoints(par,3,NULL);
unur_tdrgw_set_max_intervals(par,10);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[13],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[13]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[13],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [14] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[14]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[14],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[14]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[14],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[14]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_tdrgw_set_cpoints(par,3,NULL);
unur_tdrgw_set_max_intervals(par,10);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[14],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[14]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[14],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [15] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[15]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[15],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[15]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[15],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[15]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_tdrgw_set_cpoints(par,3,NULL);
unur_tdrgw_set_max_intervals(par,10);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[15],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[15]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[15],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [16] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[16]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[16],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[16]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[16],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[16]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_tdrgw_set_cpoints(par,3,NULL);
unur_tdrgw_set_max_intervals(par,10);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[16],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[16]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[16],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [17] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[17]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[17],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[17]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[17],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[17]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[17],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [18] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[18]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[18],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[18]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[18],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[18]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[18],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [19] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[19]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[19],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[19]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[19],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[19]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[19],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [20] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[20]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[20],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[20]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[20],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[20]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[20],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [21] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[21]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[21],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[21]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[21],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[21]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_tdrgw_set_cpoints(par,3,NULL);
unur_tdrgw_set_max_intervals(par,10);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[21],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[21]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[21],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[21]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[21],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[21]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 2, NULL );
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[21],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[21]);
	unur_errno = 0;
double perc[] = {0.1,0.3,0.5,0.7,0.9};
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 5, perc );
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[21],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [22] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[22]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[22],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[22]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[22],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[22]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_tdrgw_set_cpoints(par,3,NULL);
unur_tdrgw_set_max_intervals(par,10);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[22],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[22]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[22],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[22]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[22],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[22]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 2, NULL );
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[22],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[22]);
	unur_errno = 0;
double perc[] = {0.1,0.3,0.5,0.7,0.9};
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 5, perc );
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[22],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [23] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[23]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[23],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[23]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[23],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[23]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_tdrgw_set_cpoints(par,3,NULL);
unur_tdrgw_set_max_intervals(par,10);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[23],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[23]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[23],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[23]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[23],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[23]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 2, NULL );
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[23],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[23]);
	unur_errno = 0;
double perc[] = {0.1,0.3,0.5,0.7,0.9};
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 5, perc );
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[23],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [24] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[24]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[24],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[24]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[24],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[24]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[24],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[24]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[24],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[24]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 2, NULL );
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[24],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[24]);
	unur_errno = 0;
double perc[] = {0.1,0.3,0.5,0.7,0.9};
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 5, perc );
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[24],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [25] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[25]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[25],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[25]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[25],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[25]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[25],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[25]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[25],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[25]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 2, NULL );
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[25],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[25]);
	unur_errno = 0;
double perc[] = {0.1,0.3,0.5,0.7,0.9};
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 5, perc );
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[25],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [26] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[26]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[26],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[26]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[26],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[26]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_tdrgw_set_cpoints(par,3,NULL);
unur_tdrgw_set_max_intervals(par,10);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[26],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[26]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[26],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[26]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[26],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[26]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 2, NULL );
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[26],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[26]);
	unur_errno = 0;
double perc[] = {0.1,0.3,0.5,0.7,0.9};
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 5, perc );
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[26],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [27] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[27]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[27],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[27]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[27],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[27]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_tdrgw_set_cpoints(par,3,NULL);
unur_tdrgw_set_max_intervals(par,10);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[27],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[27]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[27],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[27]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[27],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[27]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 2, NULL );
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[27],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[27]);
	unur_errno = 0;
double perc[] = {0.1,0.3,0.5,0.7,0.9};
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 5, perc );
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[27],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [28] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[28]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[28],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[28]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[28],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[28]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_tdrgw_set_cpoints(par,3,NULL);
unur_tdrgw_set_max_intervals(par,10);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[28],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[28]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[28],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[28]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[28],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[28]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 2, NULL );
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[28],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[28]);
	unur_errno = 0;
double perc[] = {0.1,0.3,0.5,0.7,0.9};
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 5, perc );
unur_tdrgw_reinit(gen);	
	}
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[28],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [29] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[29]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[29],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[29]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[29],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[29]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_tdrgw_set_cpoints(par,3,NULL);
unur_tdrgw_set_max_intervals(par,10);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[29],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[29]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[29],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [30] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[30]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[30],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[30]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[30],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[30]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	rcode = run_validate_chi2(TESTLOG,0,gen,distr[30],0,'+');
	n_tests_failed += (rcode==UNUR_SUCCESS)?0:1;
	n_tests_failed += (rcode==UNUR_FAILURE)?1000:0;
	unur_free(gen);
	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("\n(verify hat) "); fflush(stdout);

/* verify hat tests: 217 */

	unur_set_default_debug(~UNUR_DEBUG_SAMPLE);
	fprintf( TESTLOG,"\nVerify Hat Test (squeeze <= PDF <= hat):\n");

/* distribution [0] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[0]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[0],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[0]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[0],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[0]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_tdrgw_set_cpoints(par,3,NULL);
unur_tdrgw_set_max_intervals(par,10);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[0],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[0]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[0],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[0]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_reinit(gen);	
	}
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[0],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[0]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 2, NULL );
unur_tdrgw_reinit(gen);	
	}
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[0],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[0]);
	unur_errno = 0;
double perc[] = {0.1,0.3,0.5,0.7,0.9};
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 5, perc );
unur_tdrgw_reinit(gen);	
	}
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[0],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [1] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[1]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[1],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[1]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[1],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[1]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_tdrgw_set_cpoints(par,3,NULL);
unur_tdrgw_set_max_intervals(par,10);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[1],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[1]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[1],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[1]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_reinit(gen);	
	}
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[1],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[1]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 2, NULL );
unur_tdrgw_reinit(gen);	
	}
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[1],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[1]);
	unur_errno = 0;
double perc[] = {0.1,0.3,0.5,0.7,0.9};
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 5, perc );
unur_tdrgw_reinit(gen);	
	}
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[1],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [2] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[2]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[2],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[2]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[2],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[2]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_tdrgw_set_cpoints(par,3,NULL);
unur_tdrgw_set_max_intervals(par,10);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[2],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[2]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[2],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[2]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_reinit(gen);	
	}
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[2],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[2]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 2, NULL );
unur_tdrgw_reinit(gen);	
	}
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[2],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[2]);
	unur_errno = 0;
double perc[] = {0.1,0.3,0.5,0.7,0.9};
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 5, perc );
unur_tdrgw_reinit(gen);	
	}
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[2],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [3] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[3]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[3],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[3]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[3],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[3]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_tdrgw_set_cpoints(par,3,NULL);
unur_tdrgw_set_max_intervals(par,10);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[3],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[3]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[3],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[3]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_reinit(gen);	
	}
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[3],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[3]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 2, NULL );
unur_tdrgw_reinit(gen);	
	}
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[3],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[3]);
	unur_errno = 0;
double perc[] = {0.1,0.3,0.5,0.7,0.9};
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 5, perc );
unur_tdrgw_reinit(gen);	
	}
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[3],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [4] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[4]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[4],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[4]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[4],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[4]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_tdrgw_set_cpoints(par,3,NULL);
unur_tdrgw_set_max_intervals(par,10);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[4],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[4]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[4],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[4]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_reinit(gen);	
	}
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[4],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[4]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 2, NULL );
unur_tdrgw_reinit(gen);	
	}
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[4],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[4]);
	unur_errno = 0;
double perc[] = {0.1,0.3,0.5,0.7,0.9};
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 5, perc );
unur_tdrgw_reinit(gen);	
	}
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[4],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [5] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[5]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[5],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[5]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[5],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[5]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_tdrgw_set_cpoints(par,3,NULL);
unur_tdrgw_set_max_intervals(par,10);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[5],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[5]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[5],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[5]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_reinit(gen);	
	}
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[5],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[5]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 2, NULL );
unur_tdrgw_reinit(gen);	
	}
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[5],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[5]);
	unur_errno = 0;
double perc[] = {0.1,0.3,0.5,0.7,0.9};
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 5, perc );
unur_tdrgw_reinit(gen);	
	}
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[5],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [6] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[6]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[6],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[6]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[6],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[6]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_tdrgw_set_cpoints(par,3,NULL);
unur_tdrgw_set_max_intervals(par,10);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[6],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[6]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[6],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[6]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_reinit(gen);	
	}
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[6],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[6]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 2, NULL );
unur_tdrgw_reinit(gen);	
	}
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[6],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[6]);
	unur_errno = 0;
double perc[] = {0.1,0.3,0.5,0.7,0.9};
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 5, perc );
unur_tdrgw_reinit(gen);	
	}
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[6],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [7] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[7]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[7],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[7]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[7],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[7]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_tdrgw_set_cpoints(par,3,NULL);
unur_tdrgw_set_max_intervals(par,10);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[7],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[7]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[7],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[7]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_reinit(gen);	
	}
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[7],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[7]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 2, NULL );
unur_tdrgw_reinit(gen);	
	}
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[7],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[7]);
	unur_errno = 0;
double perc[] = {0.1,0.3,0.5,0.7,0.9};
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 5, perc );
unur_tdrgw_reinit(gen);	
	}
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[7],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [8] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[8]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[8],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[8]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[8],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[8]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_tdrgw_set_cpoints(par,3,NULL);
unur_tdrgw_set_max_intervals(par,10);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[8],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[8]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[8],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[8]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_reinit(gen);	
	}
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[8],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[8]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 2, NULL );
unur_tdrgw_reinit(gen);	
	}
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[8],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[8]);
	unur_errno = 0;
double perc[] = {0.1,0.3,0.5,0.7,0.9};
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 5, perc );
unur_tdrgw_reinit(gen);	
	}
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[8],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [9] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[9]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[9],'-')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[9]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[9],'-')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[9]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_tdrgw_set_cpoints(par,3,NULL);
unur_tdrgw_set_max_intervals(par,10);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[9],'-')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[9]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[9],'-')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [10] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[10]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[10],'-')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[10]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[10],'-')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[10]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[10],'-')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [11] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[11]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[11],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[11]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[11],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[11]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_tdrgw_set_cpoints(par,3,NULL);
unur_tdrgw_set_max_intervals(par,10);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[11],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[11]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[11],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[11]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_reinit(gen);	
	}
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[11],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[11]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 2, NULL );
unur_tdrgw_reinit(gen);	
	}
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[11],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[11]);
	unur_errno = 0;
double perc[] = {0.1,0.3,0.5,0.7,0.9};
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 5, perc );
unur_tdrgw_reinit(gen);	
	}
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[11],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [12] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[12]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[12],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[12]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[12],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[12]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_tdrgw_set_cpoints(par,3,NULL);
unur_tdrgw_set_max_intervals(par,10);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[12],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[12]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[12],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [13] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[13]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[13],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[13]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[13],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[13]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_tdrgw_set_cpoints(par,3,NULL);
unur_tdrgw_set_max_intervals(par,10);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[13],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[13]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[13],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [14] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[14]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[14],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[14]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[14],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[14]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_tdrgw_set_cpoints(par,3,NULL);
unur_tdrgw_set_max_intervals(par,10);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[14],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[14]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[14],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [15] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[15]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[15],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[15]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[15],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[15]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_tdrgw_set_cpoints(par,3,NULL);
unur_tdrgw_set_max_intervals(par,10);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[15],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[15]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[15],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [16] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[16]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[16],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[16]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[16],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[16]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_tdrgw_set_cpoints(par,3,NULL);
unur_tdrgw_set_max_intervals(par,10);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[16],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[16]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[16],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [17] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[17]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[17],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[17]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[17],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[17]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[17],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [18] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[18]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[18],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[18]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[18],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[18]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[18],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [19] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[19]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[19],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[19]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[19],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[19]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[19],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [20] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[20]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[20],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[20]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[20],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[20]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[20],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [21] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[21]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[21],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[21]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[21],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[21]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_tdrgw_set_cpoints(par,3,NULL);
unur_tdrgw_set_max_intervals(par,10);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[21],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[21]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[21],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[21]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_reinit(gen);	
	}
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[21],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[21]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 2, NULL );
unur_tdrgw_reinit(gen);	
	}
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[21],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[21]);
	unur_errno = 0;
double perc[] = {0.1,0.3,0.5,0.7,0.9};
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 5, perc );
unur_tdrgw_reinit(gen);	
	}
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[21],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [22] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[22]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[22],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[22]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[22],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[22]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_tdrgw_set_cpoints(par,3,NULL);
unur_tdrgw_set_max_intervals(par,10);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[22],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[22]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[22],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[22]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_reinit(gen);	
	}
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[22],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[22]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 2, NULL );
unur_tdrgw_reinit(gen);	
	}
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[22],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[22]);
	unur_errno = 0;
double perc[] = {0.1,0.3,0.5,0.7,0.9};
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 5, perc );
unur_tdrgw_reinit(gen);	
	}
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[22],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [23] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[23]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[23],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[23]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[23],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[23]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_tdrgw_set_cpoints(par,3,NULL);
unur_tdrgw_set_max_intervals(par,10);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[23],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[23]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[23],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[23]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_reinit(gen);	
	}
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[23],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[23]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 2, NULL );
unur_tdrgw_reinit(gen);	
	}
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[23],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[23]);
	unur_errno = 0;
double perc[] = {0.1,0.3,0.5,0.7,0.9};
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 5, perc );
unur_tdrgw_reinit(gen);	
	}
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[23],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [24] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[24]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[24],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[24]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[24],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[24]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[24],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[24]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_reinit(gen);	
	}
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[24],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[24]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 2, NULL );
unur_tdrgw_reinit(gen);	
	}
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[24],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[24]);
	unur_errno = 0;
double perc[] = {0.1,0.3,0.5,0.7,0.9};
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 5, perc );
unur_tdrgw_reinit(gen);	
	}
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[24],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [25] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[25]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[25],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[25]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[25],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[25]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[25],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[25]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_reinit(gen);	
	}
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[25],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[25]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 2, NULL );
unur_tdrgw_reinit(gen);	
	}
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[25],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[25]);
	unur_errno = 0;
double perc[] = {0.1,0.3,0.5,0.7,0.9};
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 5, perc );
unur_tdrgw_reinit(gen);	
	}
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[25],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [26] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[26]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[26],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[26]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[26],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[26]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_tdrgw_set_cpoints(par,3,NULL);
unur_tdrgw_set_max_intervals(par,10);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[26],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[26]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[26],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[26]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_reinit(gen);	
	}
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[26],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[26]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 2, NULL );
unur_tdrgw_reinit(gen);	
	}
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[26],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[26]);
	unur_errno = 0;
double perc[] = {0.1,0.3,0.5,0.7,0.9};
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 5, perc );
unur_tdrgw_reinit(gen);	
	}
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[26],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [27] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[27]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[27],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[27]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[27],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[27]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_tdrgw_set_cpoints(par,3,NULL);
unur_tdrgw_set_max_intervals(par,10);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[27],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[27]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[27],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[27]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_reinit(gen);	
	}
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[27],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[27]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 2, NULL );
unur_tdrgw_reinit(gen);	
	}
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[27],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[27]);
	unur_errno = 0;
double perc[] = {0.1,0.3,0.5,0.7,0.9};
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 5, perc );
unur_tdrgw_reinit(gen);	
	}
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[27],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [28] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[28]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[28],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[28]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[28],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[28]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_tdrgw_set_cpoints(par,3,NULL);
unur_tdrgw_set_max_intervals(par,10);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[28],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[28]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[28],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[28]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_reinit(gen);	
	}
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[28],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[28]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 2, NULL );
unur_tdrgw_reinit(gen);	
	}
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[28],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[28]);
	unur_errno = 0;
double perc[] = {0.1,0.3,0.5,0.7,0.9};
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,10,NULL);
fpm[0] = 1.;
fpm[1] = 4.;
unur_distr_cont_set_pdfparams(distr_localcopy,fpm,2);
	gen = unur_init(par);
	if (gen) {
unur_tdrgw_chg_reinit_percentiles(gen, 5, perc );
unur_tdrgw_reinit(gen);	
	}
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[28],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

/* distribution [29] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[29]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[29],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[29]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[29],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[29]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_tdrgw_set_cpoints(par,3,NULL);
unur_tdrgw_set_max_intervals(par,10);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[29],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[29]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[29],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [30] */

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[30]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[30],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[30]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[30],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	do {
	UNUR_DISTR *distr_localcopy = unur_distr_clone(distr[30]);
	unur_errno = 0;
par = unur_tdrgw_new(distr_localcopy);
	unur_tdrgw_set_pedantic(par,0);
unur_set_use_distr_privatecopy(par,FALSE);
unur_tdrgw_set_cpoints(par,30,NULL);
	gen = unur_init(par);
	if (gen) unur_tdrgw_chg_verify(gen,1);
	n_tests_failed += (run_validate_verifyhat(TESTLOG,0,gen,distr[30],'~')==UNUR_SUCCESS)?0:1000;
	unur_free(gen);

	unur_distr_free(distr_localcopy);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);


/* free distributions */
	unur_distr_free(distr[0]);
	unur_distr_free(distr[1]);
	unur_distr_free(distr[2]);
	unur_distr_free(distr[3]);
	unur_distr_free(distr[4]);
	unur_distr_free(distr[5]);
	unur_distr_free(distr[6]);
	unur_distr_free(distr[7]);
	unur_distr_free(distr[8]);
	unur_distr_free(distr[9]);
	unur_distr_free(distr[10]);
	unur_distr_free(distr[11]);
	unur_distr_free(distr[12]);
	unur_distr_free(distr[13]);
	unur_distr_free(distr[14]);
	unur_distr_free(distr[15]);
	unur_distr_free(distr[16]);
	unur_distr_free(distr[17]);
	unur_distr_free(distr[18]);
	unur_distr_free(distr[19]);
	unur_distr_free(distr[20]);
	unur_distr_free(distr[21]);
	unur_distr_free(distr[22]);
	unur_distr_free(distr[23]);
	unur_distr_free(distr[24]);
	unur_distr_free(distr[25]);
	unur_distr_free(distr[26]);
	unur_distr_free(distr[27]);
	unur_distr_free(distr[28]);
	unur_distr_free(distr[29]);
	unur_distr_free(distr[30]);
#if WITH_DMALLOC
	dmalloc_vmessage("section = validate  ================================\n","");
	dmalloc_log_unfreed();
#endif


	/* test finished */
	test_ok &= (n_tests_failed>CHI2_FAILURES_TOLERATED) ? 0 : 1;
	/* we accept CHI2_FAILURES_TOLERATED failures */
	(n_tests_failed>CHI2_FAILURES_TOLERATED) ? printf(" ==> failed] ") : printf(" ==> ok] ");

	/* prevent compiler from making useless annoying warnings */
	distr[0] = NULL;
	par = NULL;
	gen = NULL;
	darray = NULL;
	fpm[0] = 0.;

} /* end of test_validate */


/*---------------------------------------------------------------------------*/
/* run generator in verifying mode */

void run_verify_generator( FILE *LOG, int line, UNUR_PAR *par )
{
	UNUR_GEN *gen;
	int i;

	/* switch to verifying mode */
	unur_tdrgw_set_verify(par,1);

	/* initialize generator */
	gen = unur_init( par ); abort_if_NULL(LOG, line, gen);

	/* run generator */
	for (i=0; i<VIOLATE_SAMPLE_SIZE; i++)
		unur_sample_cont(gen);

	/* destroy generator */
	unur_free(gen); 

} /* end of run_verify_generator() */


/*---------------------------------------------------------------------------*/

int main()
{ 
	/* open log file for unuran and set output stream for unuran messages */
	UNURANLOG = fopen( "t_tdrgw_unuran.log","w" );
	abort_if_NULL( stderr,-1, UNURANLOG );
	unur_set_stream( UNURANLOG );

	/* open log file for testing */
	TESTLOG = fopen( "t_tdrgw_test.log","w" );
	abort_if_NULL( stderr,-1, TESTLOG );

	/* write header into log file */
  	{
		time_t started;  
		fprintf(TESTLOG,"\nUNURAN - Universal Non-Uniform RANdom number generator\n\n");
		if (time( &started ) != -1)
			fprintf(TESTLOG,"%s",ctime(&started));
		fprintf(TESTLOG,"\n====================================================\n\n");
	}

        /* seed build-in uniform generators */
        unur_urng_MRG31k3p_seed(311736);
	unur_urng_fish_seed(311736);
	unur_urng_mstd_seed(311736);

	/* seed uniform random number generator */
#if UNUR_URNG_TYPE == UNUR_URNG_GENERIC
/*
	if (unur_urng_seed(NULL, 311736) != UNUR_SUCCESS) {
	  fprintf(stderr,"WARNING: Seed could not be set at random\n");
	}  
*/
#elif UNUR_URNG_TYPE == UNUR_URNG_PRNG
	unur_set_default_urng(prng_new("mt19937(311736)"));
#elif UNUR_URNG_TYPE == UNUR_URNG_RNGSTREAM
	{
	    unsigned long seed[6] = {311736,311736,311736,311736,311736,311736};
	    RngStream_SetPackageSeed(seed);
	}
#endif  /* UNUR_URNG_TYPE */

	/* set default debugging flag */
	unur_set_default_debug(UNUR_DEBUG_ALL);

	/* start test */
	printf("tdrgw: ");

	/* run tests */
test_new();
test_set();
test_get();
test_chg();
test_init();
test_reinit();
test_sample();
test_validate();


	/* test finished */
	printf("\n");  fflush(stdout);

	/* close log files */
	fprintf(TESTLOG,"\n====================================================\n\n");
	if (test_ok)
		fprintf(TESTLOG,"All tests PASSED.\n");
	else
		fprintf(TESTLOG,"Test(s) FAILED.\n");

	fclose(UNURANLOG);
	fclose(TESTLOG);

	/* free memory */
        compare_free_memory();

	/* exit */
	exit( (test_ok) ? EXIT_SUCCESS : EXIT_FAILURE );

} /* end of main */

